package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.command.CommandHandler;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.config.configs.RequestConfig;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Evaluation;
import cz.zcu.fav.kiv.mjakubas.saf.io.export.EntityExporter;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import cz.zcu.fav.kiv.mjakubas.saf.request.EntitiesRequestResult;
import cz.zcu.fav.kiv.mjakubas.saf.request.EntitiesRequests;
import org.jetbrains.annotations.NotNull;

public class EvaluationsCommandsHandler {

    private final RequestConfig config;

    public EvaluationsCommandsHandler(RequestConfig config) {
        this.config = config;
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.get}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetAll(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            Evaluation[] evaluations = (Evaluation[]) EntitiesRequests.get(config,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY,
                    Evaluation.class).getDeserializedEntities();
            EntityExporter.export(evaluations, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.println("Evaluations successfully queried!");
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.get}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            Evaluation[] evaluations = (Evaluation[]) EntitiesRequests.get(config,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    Evaluation.class).getDeserializedEntities();
            EntityExporter.export(evaluations, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Evaluation with id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.get}", "{query.sub.byStudentsSubject}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByStudentSubjectID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            Evaluation[] evaluations = (Evaluation[]) EntitiesRequests.get(config,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.STUDENTSSUBJECT_QUERY + RequestConfig.ID_QUERY +
                            "/" + id,
                    Evaluation.class).getDeserializedEntities();
            EntityExporter.export(evaluations, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Evaluation with students subject id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.get}", "{query.sub.byStudentsSubject}", "<java.lang.Integer>",
            "{query.sub.doAverage}"})
    public void handleGetAverageByStudentSubjectID(Integer id)
            throws CommandException {
        try {
            EntitiesRequestResult r = EntitiesRequests.get(config,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.AVERAGE_QUERY +
                            RequestConfig.STUDENTSSUBJECT_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    Evaluation.class);
            System.out.println(r.getHttpResponseResult().getResponse());
        } catch (Exception e) {
            throw new CommandException(e);
        }
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.post}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePost(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            Evaluation[] evaluations = (Evaluation[]) EntityExporter.importToObjects(fileType, filePath, Evaluation.class);
            EntitiesRequests.post(config, RequestConfig.EVALUATIONS_ENTITIES_QUERY, evaluations);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Evaluation/Evaluations successfully created!%n");
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.put}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePutByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            Evaluation[] evaluations = (Evaluation[]) EntityExporter.importToObjects(fileType, filePath, Evaluation.class);
            EntitiesRequests.put(config, RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    evaluations[0]);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Evaluation with id: %d successfully modified!%n", id);
    }

    @CommandHandler({"{query.evaluations}", "{httpMethod.delete}", "<java.lang.Integer>"})
    public void handleDeleteByID(Integer id)
            throws CommandException {
        String msg;
        try {
            msg = EntitiesRequests.delete(config,
                            RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id).
                    getHttpResponseResult().getResponse();
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Evaluation with id: %d successfully deleted!%n", id);
    }
}
