package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.command.CommandHandler;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.config.configs.RequestConfig;
import cz.zcu.fav.kiv.mjakubas.saf.entity.ScheduleAction;
import cz.zcu.fav.kiv.mjakubas.saf.io.export.EntityExporter;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import cz.zcu.fav.kiv.mjakubas.saf.request.EntitiesRequests;
import org.jetbrains.annotations.NotNull;

public class ScheduleActionsCommandsHandler {

    private final RequestConfig config;

    public ScheduleActionsCommandsHandler(RequestConfig config) {
        this.config = config;
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.get}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetAll(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntitiesRequests.get(config,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY,
                    ScheduleAction.class).getDeserializedEntities();
            EntityExporter.export(scheduleActions, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.println("Schedule actions successfully queried!");
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.get}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntitiesRequests.get(config,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    ScheduleAction.class).getDeserializedEntities();
            EntityExporter.export(scheduleActions, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action with id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.get}", "{query.sub.byRoom}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByRoomID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntitiesRequests.get(config,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.ID_QUERY +
                            "/" + id,
                    ScheduleAction.class).getDeserializedEntities();
            EntityExporter.export(scheduleActions, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action with room id: %s successfully queried!%n", id);
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.get}", "{query.sub.byRoom}", "{query.sub.byName}",
            "<java.lang.String>", "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByRoomName(@NotNull String name, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntitiesRequests.get(config,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.NAME_QUERY +
                            "/" + name,
                    ScheduleAction.class).getDeserializedEntities();
            EntityExporter.export(scheduleActions, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action with room name: %s successfully queried!%n", name);
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.get}", "{query.sub.bySubject}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetBySubjectID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntitiesRequests.get(config,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY +
                            "/" + id,
                    ScheduleAction.class).getDeserializedEntities();
            EntityExporter.export(scheduleActions, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action with subject id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.get}", "{query.sub.bySubject}", "{query.sub.byName}",
            "<java.lang.String>", "[query.sub.type]", "<java.lang.String>"})
    public void handleGetBySubjectName(@NotNull String name, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntitiesRequests.get(config,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY
                            + "/" + name,
                    ScheduleAction.class).getDeserializedEntities();
            EntityExporter.export(scheduleActions, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action with subject name: %s successfully queried!%n", name);
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.post}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePost(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntityExporter.importToObjects(fileType, filePath, ScheduleAction.class);
            EntitiesRequests.post(config, RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY, scheduleActions);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action/Schedule actions successfully created!%n");
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.put}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePutByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            ScheduleAction[] scheduleActions = (ScheduleAction[]) EntityExporter.importToObjects(fileType, filePath, ScheduleAction.class);
            EntitiesRequests.put(config, RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/"
                    + id, scheduleActions[0]);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule Action with id: %d successfully modified!%n", id);
    }

    @CommandHandler({"{query.scheduleActions}", "{httpMethod.delete}", "<java.lang.Integer>"})
    public void handleDeleteByID(Integer id)
            throws CommandException {
        String msg;
        try {
            msg = EntitiesRequests.delete(config,
                            RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id).
                    getHttpResponseResult().getResponse();
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Schedule action with id: %d successfully deleted!%n", id);
    }
}
