package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.command.CommandHandler;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.config.configs.RequestConfig;
import cz.zcu.fav.kiv.mjakubas.saf.entity.SchoolDay;
import cz.zcu.fav.kiv.mjakubas.saf.io.export.EntityExporter;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import cz.zcu.fav.kiv.mjakubas.saf.request.EntitiesRequests;
import org.jetbrains.annotations.NotNull;

public class SchoolDaysCommandsHandler {

    private final RequestConfig config;

    public SchoolDaysCommandsHandler(RequestConfig config) {
        this.config = config;
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.get}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetAll(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntitiesRequests.get(config,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY,
                    SchoolDay.class).getDeserializedEntities();
            EntityExporter.export(schoolDays, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.println("School days successfully queried!");
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.get}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntitiesRequests.get(config,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    SchoolDay.class).getDeserializedEntities();
            EntityExporter.export(schoolDays, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day with id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.get}", "{query.sub.byName}", "<java.lang.String>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByName(@NotNull String name, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntitiesRequests.get(config,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/" + name,
                    SchoolDay.class).getDeserializedEntities();
            EntityExporter.export(schoolDays, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day with name: %s successfully queried!%n", name);
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.get}", "{query.sub.byScheduleAction}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByScheduleActionID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntitiesRequests.get(config,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTION_QUERY + RequestConfig.ID_QUERY +
                            "/" + id,
                    SchoolDay.class).getDeserializedEntities();
            EntityExporter.export(schoolDays, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day with schedule action id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.get}", "{query.sub.byScheduleActionDate}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByScheduleActionDateEntityID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntitiesRequests.get(config,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTIONDATE_QUERY + RequestConfig.ID_QUERY +
                            "/" + id,
                    SchoolDay.class).getDeserializedEntities();
            EntityExporter.export(schoolDays, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day with schedule action date id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.post}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePost(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntityExporter.importToObjects(fileType, filePath, SchoolDay.class);
            EntitiesRequests.post(config, RequestConfig.SCHOOLDAYS_ENTITIES_QUERY, schoolDays);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day/School days successfully created!%n");
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.put}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePutByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SchoolDay[] schoolDays = (SchoolDay[]) EntityExporter.importToObjects(fileType, filePath, SchoolDay.class);
            EntitiesRequests.put(config, RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    schoolDays[0]);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day with id: %d successfully modified!%n", id);
    }

    @CommandHandler({"{query.schoolDays}", "{httpMethod.delete}", "<java.lang.Integer>"})
    public void handleDeleteByID(Integer id)
            throws CommandException {
        String msg;
        try {
            msg = EntitiesRequests.delete(config,
                            RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id).
                    getHttpResponseResult().getResponse();
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("School day with id: %d successfully deleted!%n", id);
    }
}
