package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.command.CommandHandler;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.config.configs.RequestConfig;
import cz.zcu.fav.kiv.mjakubas.saf.entity.SubjectList;
import cz.zcu.fav.kiv.mjakubas.saf.io.export.EntityExporter;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import cz.zcu.fav.kiv.mjakubas.saf.request.EntitiesRequests;
import org.jetbrains.annotations.NotNull;

public class SubjectListsCommandsHandler {

    private final RequestConfig config;

    public SubjectListsCommandsHandler(RequestConfig config) {
        this.config = config;
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetAll(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.println("Subject lists successfully queried!");
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}", "{query.sub.byName}", "<java.lang.String>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByName(@NotNull String name, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/" + name,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with name: %s successfully queried!%n", name);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}", "{query.sub.bySubject}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetBySubjectID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY
                            + "/" + id,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with subject id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}", "{query.sub.bySubject}", "{query.sub.byName}",
            "<java.lang.String>", "[query.sub.type]", "<java.lang.String>"})
    public void handleGetBySubjectName(@NotNull String name, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY +
                            "/" + name,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with subject name: %s successfully queried!%n", name);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}", "{query.sub.byTeacher}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByTeacherID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY + RequestConfig.ID_QUERY
                            + "/" + id,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with teacher id: %d successfully queried!%n", id);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.get}", "{query.sub.byTeacher}", "{query.sub.byName}",
            "<java.lang.String>", "{query.sub.bySurname}", "<java.lang.String>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handleGetByTeacherFirstAndLastName(@NotNull String firstName, @NotNull String lastName,
                                                   @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntitiesRequests.get(config,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY + RequestConfig.NAME_QUERY +
                            "/" + firstName + "/" + lastName,
                    SubjectList.class).getDeserializedEntities();
            EntityExporter.export(subjectLists, fileType, filePath);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with teacher name: %s surname: %s successfully queried!%n", firstName, lastName);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.post}",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePost(@NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntityExporter.importToObjects(fileType, filePath, SubjectList.class);
            EntitiesRequests.post(config, RequestConfig.SUBJECTLISTS_ENTITIES_QUERY, subjectLists);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list/Subject lists successfully created!%n");
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.put}", "<java.lang.Integer>",
            "[query.sub.type]", "<java.lang.String>"})
    public void handlePutByID(Integer id, @NotNull FileType fileType, @NotNull String filePath)
            throws CommandException {
        try {
            SubjectList[] subjectLists = (SubjectList[]) EntityExporter.importToObjects(fileType, filePath, SubjectList.class);
            EntitiesRequests.put(config, RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id,
                    subjectLists[0]);
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with id: %d successfully modified!%n", id);
    }

    @CommandHandler({"{query.subjectLists}", "{httpMethod.delete}", "<java.lang.Integer>"})
    public void handleDeleteByID(Integer id)
            throws CommandException {
        String msg;
        try {
            msg = EntitiesRequests.delete(config,
                            RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + id).
                    getHttpResponseResult().getResponse();
        } catch (Exception e) {
            throw new CommandException(e);
        }
        System.out.printf("Subject list with id: %d successfully deleted!%n", id);
    }
}
