package cz.zcu.fav.kiv.mjakubas.saf.entity;

import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * Represents Absence entity from a backend of school agenda.
 */
@JsonInclude(JsonInclude.Include.NON_DEFAULT)
public final class Absence extends ASimpleEntity {

    private int idAbsences;
    private int idStudents;
    private int idScheduleactiondates;

    private Student student;
    private ScheduleActionDate scheduleactionsdate;

    // constructors

    /**
     * Instantiates new empty Absence entity.
     */
    public Absence() {
    }

    /**
     * Instantiates new Absence entity with all its fields.
     *
     * @param idAbsences            absence id
     * @param idStudents            absence student id
     * @param idScheduleactiondates absence schedule action dates id
     */
    public Absence(int idAbsences, int idStudents, int idScheduleactiondates) {
        this.idAbsences = idAbsences;
        this.idStudents = idStudents;
        this.idScheduleactiondates = idScheduleactiondates;
    }

    // override

    @Override
    public int getID() {
        return idAbsences;
    }

    @Override
    public String getSimpleIdentifier() {
        StringBuilder identifierBuilder = new StringBuilder();

        String studentIdentifier = (student != null) ? student.getIdentifier() : "";
        String scheduleActionDateIdentifier = (scheduleactionsdate != null) ? scheduleactionsdate.getIdentifier() : "";
        identifierBuilder.append(studentIdentifier).append(scheduleActionDateIdentifier);

        return identifierBuilder.toString();
    }

    // get

    /**
     * Get absence id.
     *
     * @return absence id
     */
    public int getIdAbsences() {
        return idAbsences;
    }

    /**
     * Get absence student id.
     *
     * @return absence student id
     */
    public int getIdStudents() {
        return idStudents;
    }

    /**
     * Get absence schedule action dates id.
     *
     * @return absence schedule action dates id
     */
    public int getIdScheduleactiondates() {
        return idScheduleactiondates;
    }

    /**
     * Get absence student.
     *
     * @return absence student
     */
    public Student getStudent() {
        return student;
    }

    /**
     * Get absence schedule action date.
     *
     * @return absence schedule action date
     */
    public ScheduleActionDate getScheduleactionsdate() {
        return scheduleactionsdate;
    }

    // set

    /**
     * Set absence id.
     *
     * @param idAbsences absence id
     */
    public void setIdAbsences(int idAbsences) {
        this.idAbsences = idAbsences;
    }

    /**
     * Set absence student id.
     *
     * @param idStudents absence student id
     */
    public void setIdStudents(int idStudents) {
        this.idStudents = idStudents;
    }

    /**
     * Set absence schedule action dates id.
     *
     * @param idScheduleactiondates absence schedule action dates id
     */
    public void setIdScheduleactiondates(int idScheduleactiondates) {
        this.idScheduleactiondates = idScheduleactiondates;
    }

    /**
     * Set absence student.
     *
     * @param student absence student
     */
    public void setStudent(Student student) {
        this.student = student;
    }

    /**
     * Set absence schedule action dates.
     *
     * @param scheduleactionsdate absence schedule action dates
     */
    public void setScheduleactionsdate(ScheduleActionDate scheduleactionsdate) {
        this.scheduleactionsdate = scheduleactionsdate;
    }
}
