package cz.zcu.fav.kiv.mjakubas.saf.entity;

import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * Represents Evaluation entity from a backend of school agenda.
 */
@JsonInclude(JsonInclude.Include.NON_DEFAULT)
public final class Evaluation extends ASimpleEntity {

    private int idEvaluations;
    private String testName;
    private int weight;
    private float grade;
    private StudentsSubject studentssubject;

    // constructors

    /**
     * Instantiates new empty Evaluation entity.
     */
    public Evaluation() {
    }

    /**
     * Instantiates new Evaluation entity with all its fields.
     *
     * @param idEvaluations evaluation id
     * @param testName      evaluation test name
     * @param weight        evaluation weight
     * @param grade         evaluation grade
     */
    public Evaluation(int idEvaluations, String testName, int weight, float grade) {
        this.idEvaluations = idEvaluations;
        this.testName = testName;
        this.weight = weight;
        this.grade = grade;
    }

    // override

    @Override
    public int getID() {
        return idEvaluations;
    }

    @Override
    public String getSimpleIdentifier() {
        StringBuilder identifierBuilder = new StringBuilder();

        String subjectIdentifier = "";
        if (studentssubject != null) {
            subjectIdentifier = (studentssubject.getSubject() != null) ?
                    studentssubject.getSubject().getIdentifier() : "";
        }

        identifierBuilder.append(String.format("%s ", testName)).append("{").append(subjectIdentifier).append("}");

        return identifierBuilder.toString();
    }

    // get

    /**
     * Get evaluation id.
     *
     * @return evaluation id
     */
    public int getIdEvaluations() {
        return idEvaluations;
    }

    /**
     * Get evaluation test name.
     *
     * @return evaluation test name
     */
    public String getTestName() {
        return testName;
    }

    /**
     * Get evaluation weight.
     *
     * @return evaluation weight
     */
    public int getWeight() {
        return weight;
    }

    /**
     * Get evaluation grade.
     *
     * @return evaluation grade
     */
    public float getGrade() {
        return grade;
    }

    /**
     * Get evaluation students subjects.
     *
     * @return evaluation students subjects
     */
    public StudentsSubject getStudentssubject() {
        return studentssubject;
    }

    // set

    /**
     * Set evaluation id.
     *
     * @param idEvaluations evaluation id
     */
    public void setIdEvaluations(int idEvaluations) {
        this.idEvaluations = idEvaluations;
    }

    /**
     * Set evaluation test name.
     *
     * @param testName evaluation test name
     */
    public void setTestName(String testName) {
        this.testName = testName;
    }

    /**
     * Set evaluation weight.
     *
     * @param weight evaluation weight
     */
    public void setWeight(int weight) {
        this.weight = weight;
    }

    /**
     * Set evaluation grade.
     *
     * @param grade evaluation grade
     */
    public void setGrade(float grade) {
        this.grade = grade;
    }

    /**
     * Set evaluation students subject.
     *
     * @param studentssubject evaluation students subject
     */
    public void setStudentssubject(StudentsSubject studentssubject) {
        this.studentssubject = studentssubject;
    }
}
