package cz.zcu.fav.kiv.mjakubas.saf.entity;

import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * Represents Room entity from a backend of school agenda.
 */
@JsonInclude(JsonInclude.Include.NON_DEFAULT)
public final class Room extends ASimpleEntity {

    private int idRooms;
    private String roomName;
    private int capacity;

    private ScheduleAction[] scheduleactions;
    private ScheduleActionDate[] scheduleactionDates;

    private Building building;

    // constructor

    /**
     * Instantiates new {@link Room}.
     */
    public Room() {
    }

    /**
     * Instantiates new {@link Room} with all its attributes.
     *
     * @param idRooms  ID of {@link Room}
     * @param roomName name of {@link Room}
     * @param capacity capacity of {@link Room}
     */
    public Room(int idRooms, String roomName, int capacity) {
        this.idRooms = idRooms;
        this.roomName = roomName;
        this.capacity = capacity;
    }

    // override

    @Override
    public int getID() {
        return idRooms;
    }

    @Override
    public String getSimpleIdentifier() {
        return roomName;
    }

    @Override
    public String toString() {
        return getIdentifier();
    }

    // get

    /**
     * Get room building.
     *
     * @return room building
     */
    public Building getBuilding() {
        return building;
    }

    /**
     * Get room schedule action.
     *
     * @return room schedule action
     */
    public ScheduleAction[] getScheduleactions() {
        return scheduleactions;
    }

    /**
     * Get room id.
     *
     * @return room id
     */
    public int getIdRooms() {
        return idRooms;
    }

    /**
     * Get room name.
     *
     * @return room name
     */
    public String getRoomName() {
        return roomName;
    }

    /**
     * Get room capacity.
     *
     * @return room capacity
     */
    public int getCapacity() {
        return capacity;
    }

    /**
     * Get room schedule action dates.
     *
     * @return room schedule action dates
     */
    public ScheduleActionDate[] getScheduleactionDates() {
        return scheduleactionDates;
    }

    // set

    /**
     * Set room schedule action date.
     *
     * @param scheduleactionDates room schedule action date
     */
    public void setScheduleactionDates(ScheduleActionDate[] scheduleactionDates) {
        this.scheduleactionDates = scheduleactionDates;
    }

    /**
     * Set room building.
     *
     * @param building room building
     */
    public void setBuilding(Building building) {
        this.building = building;
    }

    /**
     * Set room schedule action dates
     *
     * @param scheduleactionDates room schedule action dates
     */
    public void setScheduleactiondates(ScheduleActionDate[] scheduleactionDates) {
        this.scheduleactionDates = scheduleactionDates;
    }

    /**
     * Set room schedule action.
     *
     * @param scheduleactions room schedule action
     */
    public void setScheduleactions(ScheduleAction[] scheduleactions) {
        this.scheduleactions = scheduleactions;
    }

    /**
     * Set room id.
     *
     * @param idRooms room id
     */
    public void setIdRooms(int idRooms) {
        this.idRooms = idRooms;
    }

    /**
     * Set room name
     *
     * @param roomName room name
     */
    public void setRoomName(String roomName) {
        this.roomName = roomName;
    }

    /**
     * Set room capacity.
     *
     * @param capacity room capacity
     */
    public void setCapacity(int capacity) {
        this.capacity = capacity;
    }
}
