package cz.zcu.fav.kiv.mjakubas.saf.entity;

import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * Represents schedule action entity from a backend of school agenda.
 */
@JsonInclude(JsonInclude.Include.NON_DEFAULT)
public final class ScheduleAction extends ASimpleEntity {

    private int idScheduleactions;
    private int idRooms;
    private int idSubjects;
    private int idSchooldays;
    private int idSchoolhours;

    private ScheduleActionDate[] scheduleactiondates;

    public ScheduleActionDate[] getScheduleactiondates() {
        return scheduleactiondates;
    }

    private Room room;
    private Subject subject;
    private SchoolDay schoolday;
    private SchoolHour schoolhour;

    // constructor

    /**
     * Instantiates new empty Schedule Action.
     */
    public ScheduleAction() {
    }

    /**
     * Instantiates new Schedule Action with all its fields.
     *
     * @param idScheduleactions schedule action id
     * @param idRooms           room id
     * @param idSubjects        subject id
     * @param idSchooldays      school day id
     * @param idSchoolhours     school hour id
     */
    public ScheduleAction(int idScheduleactions, int idRooms, int idSubjects, int idSchooldays, int idSchoolhours) {
        this.idScheduleactions = idScheduleactions;
        this.idRooms = idRooms;
        this.idSubjects = idSubjects;
        this.idSchooldays = idSchooldays;
        this.idSchoolhours = idSchoolhours;
    }

    // override

    @Override
    public int getID() {
        return idScheduleactions;
    }

    @Override
    public String getSimpleIdentifier() {
        StringBuilder identifierBuilder = new StringBuilder();

        String roomIdentifier =
                (room != null) ?
                        String.format("{[%d] %s)}", room.getIdRooms(), room.getRoomName()) : "";
        String schoolDayIdentifier =
                (schoolday != null) ? String.format(" {[%d] %s}", schoolday.getID(), schoolday.getSchooldayName()) : "";
        String schoolHourIdentifier =
                (schoolhour != null) ?
                        String.format(" {[%d] %s}", schoolhour.getID(), schoolhour.getSchoolhourName()) : "";
        identifierBuilder.append(roomIdentifier).append(schoolDayIdentifier).append(schoolHourIdentifier);

        return identifierBuilder.toString();
    }

    @Override
    public String toString() {
        return getIdentifier();
    }

    // get

    /**
     * Get schedule action id.
     *
     * @return schedule action id
     */
    public int getIdScheduleactions() {
        return idScheduleactions;
    }

    /**
     * Get schedule action room id.
     *
     * @return schedule action room id
     */
    public int getIdRooms() {
        return idRooms;
    }

    /**
     * Get schedule action subject id.
     *
     * @return schedule action subject id
     */
    public int getIdSubjects() {
        return idSubjects;
    }

    /**
     * Get schedule action school days.
     *
     * @return schedule action school days
     */
    public int getIdSchooldays() {
        return idSchooldays;
    }

    /**
     * Get schedule action school hour.
     *
     * @return schedule action school hour
     */
    public int getIdSchoolhours() {
        return idSchoolhours;
    }

    /**
     * Get schedule action room.
     *
     * @return schedule action room
     */
    public Room getRoom() {
        return room;
    }

    /**
     * Get schedule action subject.
     *
     * @return schedule action subject
     */
    public Subject getSubject() {
        return subject;
    }

    /**
     * Get schedule action school hour.
     *
     * @return schedule action school hour
     */
    public SchoolHour getSchoolhour() {
        return schoolhour;
    }

    /**
     * Get schedule action school day.
     *
     * @return schedule action school day
     */
    public SchoolDay getSchoolday() {
        return schoolday;
    }

    // set

    /**
     * Set schedule action room.
     *
     * @param room schedule action room
     */
    public void setRoom(Room room) {
        this.room = room;
    }

    /**
     * Set schedule action subject.
     *
     * @param subject schedule action subject
     */
    public void setSubject(Subject subject) {
        this.subject = subject;
    }

    /**
     * Set schedule action school day.
     *
     * @param schoolday schedule action school day
     */
    public void setSchoolday(SchoolDay schoolday) {
        this.schoolday = schoolday;
    }

    /**
     * Set schedule action school hour.
     *
     * @param schoolhour schedule action school hour
     */
    public void setSchoolhour(SchoolHour schoolhour) {
        this.schoolhour = schoolhour;
    }

    /**
     * Set schedule action date.
     *
     * @param scheduleactiondates schedule action date
     */
    public void setScheduleactiondates(ScheduleActionDate[] scheduleactiondates) {
        this.scheduleactiondates = scheduleactiondates;
    }

    /**
     * Set schedule action id.
     *
     * @param idScheduleactions schedule action id
     */
    public void setIdScheduleactions(int idScheduleactions) {
        this.idScheduleactions = idScheduleactions;
    }

    /**
     * Set schedule action room id.
     *
     * @param idRooms schedule action room id
     */
    public void setIdRooms(int idRooms) {
        this.idRooms = idRooms;
    }

    /**
     * Set schedule action subjects.
     *
     * @param idSubjects schedule action subjects
     */
    public void setIdSubjects(int idSubjects) {
        this.idSubjects = idSubjects;
    }

    /**
     * Set schedule action school day id.
     *
     * @param idSchooldays schedule action school day id
     */
    public void setIdSchooldays(int idSchooldays) {
        this.idSchooldays = idSchooldays;
    }

    /**
     * Set schedule action school hour id.
     *
     * @param idSchoolhours schedule action school hour id
     */
    public void setIdSchoolhours(int idSchoolhours) {
        this.idSchoolhours = idSchoolhours;
    }
}
