package cz.zcu.fav.kiv.mjakubas.saf.entity;

import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * Represents a Student entity implementation for frontend of school agenda.
 */
@JsonInclude(JsonInclude.Include.NON_DEFAULT)
public final class Student extends ASimpleEntity {

    private int idStudents;
    private String firstName;
    private String lastName;
    private String birthDate;
    private String residence;
    private int phone;
    private String email;

    private Subject[] subjects;
    private Absence[] absences;
    private StudentsSubject[] studentssubjects;

    private SchoolClass classesEntity;

    // constructors

    /**
     * Instantiates new empty Student entity.
     */
    public Student() {
    }

    /**
     * Instantiates new Student entity with all its fields.
     *
     * @param idStudents              student id
     * @param firstName               student first name
     * @param lastName                student last name
     * @param birthDate               student birthdate
     * @param residence               student residence
     * @param phone                   student phone
     * @param email                   student email
     * @param subjects                student subject
     * @param absences                student absence
     * @param studentsSubjectEntities student subjects
     */
    public Student(int idStudents, String firstName, String lastName, String birthDate, String residence, int phone, String email, Subject[] subjects, Absence[] absences, StudentsSubject[] studentsSubjectEntities) {
        this.idStudents = idStudents;
        this.firstName = firstName;
        this.lastName = lastName;
        this.birthDate = birthDate;
        this.residence = residence;
        this.phone = phone;
        this.email = email;
        this.subjects = subjects;
        this.absences = absences;
        this.studentssubjects = studentsSubjectEntities;
    }

    // override

    @Override
    public int getID() {
        return idStudents;
    }

    @Override
    public String getSimpleIdentifier() {
        StringBuilder identifierBuilder = new StringBuilder();

        String classIdentifier = (classesEntity != null) ? classesEntity.getClassName() : "";
        identifierBuilder.append("(").append(classIdentifier).append(")");
        identifierBuilder.append(String.format(" %s %s (%s)", firstName, lastName, email));

        return identifierBuilder.toString();
    }

    @Override
    public String toString() {
        return getIdentifier();
    }

    // get

    /**
     * Get students id.
     *
     * @return students id
     */
    public int getIdStudents() {
        return idStudents;
    }

    /**
     * Get students first name.
     *
     * @return students first name
     */
    public String getFirstName() {
        return firstName;
    }

    /**
     * Get students last name.
     *
     * @return students last name
     */
    public String getLastName() {
        return lastName;
    }

    /**
     * Get students birthdate.
     *
     * @return students birthdate
     */
    public String getBirthDate() {
        return birthDate;
    }

    /**
     * Get students residence.
     *
     * @return students residence
     */
    public String getResidence() {
        return residence;
    }

    /**
     * Gets students phone.
     *
     * @return students phone
     */
    public int getPhone() {
        return phone;
    }

    /**
     * Gets students email.
     *
     * @return students email
     */
    public String getEmail() {
        return email;
    }

    /**
     * Get students subjects.
     *
     * @return students subjects
     */
    public Subject[] getSubjects() {
        return subjects;
    }

    /**
     * Get students absences.
     *
     * @return students absences
     */
    public Absence[] getAbsences() {
        return absences;
    }

    /**
     * Get students subjects.
     *
     * @return students subjects
     */
    public StudentsSubject[] getStudentssubjects() {
        return studentssubjects;
    }

    /**
     * Get students class.
     *
     * @return students class
     */
    public SchoolClass getClassesEntity() {
        return classesEntity;
    }

    // set

    /**
     * Set students id.
     *
     * @param idStudents students id
     */
    public void setIdStudents(int idStudents) {
        this.idStudents = idStudents;
    }

    /**
     * Set students first name.
     *
     * @param firstName students first name
     */
    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    /**
     * Set students last name.
     *
     * @param lastName students last name
     */
    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    /**
     * Set students birthdate.
     *
     * @param birthDate students birthdate
     */
    public void setBirthDate(String birthDate) {
        this.birthDate = birthDate;
    }

    /**
     * Set students residence.
     *
     * @param residence students residence
     */
    public void setResidence(String residence) {
        this.residence = residence;
    }

    /**
     * Set students phone.
     *
     * @param phone students phone
     */
    public void setPhone(int phone) {
        this.phone = phone;
    }

    /**
     * Set students email.
     *
     * @param email students email
     */
    public void setEmail(String email) {
        this.email = email;
    }

    /**
     * Set students subject.
     *
     * @param subjects students subject
     */
    public void setSubjects(Subject[] subjects) {
        this.subjects = subjects;
    }

    /**
     * Set students absences.
     *
     * @param absences students absences
     */
    public void setAbsences(Absence[] absences) {
        this.absences = absences;
    }

    /**
     * Set students subjects.
     *
     * @param studentssubjects students subjects
     */
    public void setStudentssubjects(StudentsSubject[] studentssubjects) {
        this.studentssubjects = studentssubjects;
    }

    /**
     * Set students class.
     *
     * @param classesEntity students class
     */
    public void setClassesEntity(SchoolClass classesEntity) {
        this.classesEntity = classesEntity;
    }
}
