package cz.zcu.fav.kiv.mjakubas.saf.entity;

import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * Represents a Teacher entity implementation for frontend of school agenda.
 */
@JsonInclude(JsonInclude.Include.NON_DEFAULT)
public final class Teacher extends ASimpleEntity {

    private int idTeachers;
    private String firstName;
    private String lastName;
    private String birthDate;
    private String commencementDate;
    private String residence;
    private int phone;
    private String email;

    private SubjectList[] subjectlists;
    private Subject[] subjects;
    private ScheduleActionDate[] scheduleActionDates;

    // constructors

    /**
     * Instantiates new empty Teacher entity.
     */
    public Teacher() {
    }

    /**
     * Instantiates new Teacher entity with all its fields.
     *
     * @param idTeachers          teacher id
     * @param firstName           teacher firsts name
     * @param lastName            teacher last name
     * @param birthDate           teacher birthdate
     * @param commencementDate    teacher commencement date
     * @param residence           teacher residence
     * @param phone               teacher phone
     * @param email               teacher email
     * @param subjectlists        teacher subjectlists
     * @param subjects            teacher subjects
     * @param scheduleActionDates teacher schedule action dates
     */
    public Teacher(int idTeachers, String firstName, String lastName, String birthDate, String commencementDate, String residence, int phone, String email, SubjectList[] subjectlists, Subject[] subjects, ScheduleActionDate[] scheduleActionDates) {
        this.idTeachers = idTeachers;
        this.firstName = firstName;
        this.lastName = lastName;
        this.birthDate = birthDate;
        this.commencementDate = commencementDate;
        this.residence = residence;
        this.phone = phone;
        this.email = email;
        this.subjectlists = subjectlists;
        this.subjects = subjects;
        this.scheduleActionDates = scheduleActionDates;
    }

    // override
    @Override
    public int getID() {
        return idTeachers;
    }

    @Override
    public String getSimpleIdentifier() {
        return String.format("%s %s (%s)", firstName, lastName, email);
    }

    @Override
    public String toString() {
        return getIdentifier();
    }

    // get

    /**
     * Get teachers id.
     *
     * @return teachers id
     */
    public int getIdTeachers() {
        return idTeachers;
    }

    /**
     * Get teachers first name.
     *
     * @return teachers first name
     */
    public String getFirstName() {
        return firstName;
    }

    /**
     * Get teachers last name.
     *
     * @return teachers last name
     */
    public String getLastName() {
        return lastName;
    }

    /**
     * Get teachers birthdate.
     *
     * @return teachers birthdate
     */
    public String getBirthDate() {
        return birthDate;
    }

    /**
     * Get teachers commencement date.
     *
     * @return teachers commencement date
     */
    public String getCommencementDate() {
        return commencementDate;
    }

    /**
     * Get teachers residence.
     *
     * @return teachers residence
     */
    public String getResidence() {
        return residence;
    }

    /**
     * Get teachers phone.
     *
     * @return teachers phone
     */
    public int getPhone() {
        return phone;
    }

    /**
     * Get teachers email.
     *
     * @return teachers email
     */
    public String getEmail() {
        return email;
    }

    /**
     * Get teachers subject lists.
     *
     * @return teachers subject lists
     */
    public SubjectList[] getSubjectlists() {
        return subjectlists;
    }

    /**
     * Get teachers subjects.
     *
     * @return teachers subjects
     */
    public Subject[] getSubjects() {
        return subjects;
    }

    /**
     * Get teachers schedule action date.
     *
     * @return teachers schedule action date
     */
    public ScheduleActionDate[] getScheduleActionDates() {
        return scheduleActionDates;
    }

    // set

    /**
     * Set teachers id.
     *
     * @param idTeachers teachers id
     */
    public void setIdTeachers(int idTeachers) {
        this.idTeachers = idTeachers;
    }

    /**
     * Set teachers first name.
     *
     * @param firstName teachers first name
     */
    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    /**
     * Set teachers last name.
     *
     * @param lastName teachers last name
     */
    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    /**
     * Set teachers birthdate.
     *
     * @param birthDate teachers birthdate
     */
    public void setBirthDate(String birthDate) {
        this.birthDate = birthDate;
    }

    /**
     * Set teachers commencement date.
     *
     * @param commencementDate teachers commencement date
     */
    public void setCommencementDate(String commencementDate) {
        this.commencementDate = commencementDate;
    }

    /**
     * Set teachers residence.
     *
     * @param residence teachers residence
     */
    public void setResidence(String residence) {
        this.residence = residence;
    }

    /**
     * Set teachers phone.
     *
     * @param phone teachers phone
     */
    public void setPhone(int phone) {
        this.phone = phone;
    }

    /**
     * Set teachers email.
     *
     * @param email teachers email
     */
    public void setEmail(String email) {
        this.email = email;
    }

    /**
     * Set teachers subject lists.
     *
     * @param subjectlists teachers subject lists
     */
    public void setSubjectlists(SubjectList[] subjectlists) {
        this.subjectlists = subjectlists;
    }

    /**
     * Set teachers subjects.
     *
     * @param subjects teachers subjects
     */
    public void setSubjects(Subject[] subjects) {
        this.subjects = subjects;
    }

    /**
     * Set teachers schedule action dates.
     *
     * @param scheduleActionDates teachers schedule action dates
     */
    public void setScheduleActionDates(ScheduleActionDate[] scheduleActionDates) {
        this.scheduleActionDates = scheduleActionDates;
    }
}
