package cz.zcu.fav.kiv.mjakubas.saf.gui.controller.category;

import cz.zcu.fav.kiv.mjakubas.saf.entity.ASimpleEntity;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.AEntityController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.FetchException;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.IModel;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.gui.view.EntitiesSearchableButtonPane;
import cz.zcu.fav.kiv.mjakubas.saf.gui.view.EntityFormsPane;
import javafx.geometry.Pos;
import javafx.scene.control.Label;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;
import org.jetbrains.annotations.NotNull;

import java.awt.*;
import java.util.List;

/**
 * Defines an abstract class for handling entity categories.
 * @param <C> entity controller
 * @param <E> entity type
 */
public abstract class ACategoryHandler<C extends AEntityController<E>, F extends IModel<E>,
        E extends ASimpleEntity> {

    protected final C entitiesController;
    protected final EntitiesSearchableButtonPane viewPane;
    protected final EntityFormsPane formsPane;

    // constructor

    public ACategoryHandler(@NotNull C entitiesController, @NotNull EntitiesSearchableButtonPane viewPane,
                            @NotNull EntityFormsPane formsPane) {
        this.entitiesController = entitiesController;
        this.viewPane = viewPane;
        this.formsPane = formsPane;
    }

    // do select

    public void doSelect() {
        try {
            //EntitiesController.getEntitiesController().purgeFetchedData();
            List<E> entities = fetchAllEntities();
            clearPreviousEntities();
            addAllEntities(entities);
            onRefresh();
            showEmptyForm();
            showCreateForm();
        } catch (FetchException e) {
            throw new RuntimeException(e);
        }
    }

    private List<E> fetchAllEntities() throws FetchException {
        return entitiesController.getAllFetchedEntities();
    }

    private void clearPreviousEntities() {
        viewPane.clearSearchableButtons();
    }

    private void addAllEntities(List<E> entities) {
        for (E entity : entities) {
            viewPane.addEntity(entity.getIdentifier(), () -> showShowForm(entity.getID()));
        }
    }

    // refresh

    public void onRefresh() {
        viewPane.setRefreshButtonAction(() -> {
            entitiesController.clearFetchedEntities();
            doSelect();
        });
    }

    // create form

    private void showCreateForm() {
        Pane createPane = entitiesController.getCreateFormPane();
        formsPane.setAndShowCreatePane(createPane);
    }

    private void showShowForm(int entityID) {
        E entity;
        try {
            entity = entitiesController.getFetchedEntity(entityID);
        } catch (FetchException e) {
            throw new RuntimeException(e);
        }

        Pane showPane = entitiesController.getShowFormPane(entity);
        formsPane.setAndShowShowPane(showPane);
    }

    private void showEmptyForm() {
        VBox box = new VBox();
        box.setAlignment(Pos.CENTER);
        Label label = new Label();
        label.textProperty().bind(I18N.getLocalizationTool().createStringBinding("empty.put"));
        box.getChildren().add(label);
        formsPane.setAndShowShowPane(box);
    }

    // get

    public EntitiesSearchableButtonPane getViewPane() {
        return viewPane;
    }
}
