package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nform;

import com.dlsc.formsfx.model.structure.Form;
import cz.zcu.fav.kiv.mjakubas.saf.entity.ASimpleEntity;
import cz.zcu.fav.kiv.mjakubas.saf.entity.StudentsSubject;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.AEntityController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.IModel;
import cz.zcu.fav.kiv.mjakubas.saf.gui.view.ViewContainer;
import javafx.beans.binding.StringBinding;
import javafx.beans.property.SimpleBooleanProperty;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.geometry.Pos;
import javafx.scene.Node;
import javafx.scene.control.Button;
import javafx.scene.control.ScrollPane;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;
import org.jetbrains.annotations.NotNull;

/**
 * Defines different possible forms of entity.
 *
 * @param <E> entity type
 */
public abstract class AForm<E extends ASimpleEntity> {

    private static final int BUTTON_HEIGHT = 40;
    private static final int BUTTON_WIDTH = 200;

    private IModel<E> emptyModel;
    private IModel<E> entityModel;

    private IModel<E> additionalModel;

    private IModel<E> additionalDeleteModel;

    private Form postForm;
    private Form editablePutForm;
    private Form additionalPutForm;

    private Form additionalPutDeleteForm;

    // constructor


    // abstract

    protected abstract AEntityController<?> getEntityController();

    protected abstract Form createPostForm(IModel<E> entityModel);

    protected abstract Pane createPostPane(Form postForm);

    protected abstract Form createEditablePutForm(IModel<E> entityModel);

    protected abstract Pane createEditablePutPane(Form editablePutForm);

    protected abstract Form createAdditionalPutForm(IModel<?> entityModel);

    protected abstract Pane createNonEditablePutPane(Form nonEditablePutForm);

    protected abstract Form createAdditionalDeletePutForm(IModel<?> entityModel);

    protected abstract Pane createNonEditableDeletePutPane(Form nonEditablePutForm);

    protected abstract IModel<E> createEmptyModel();

    protected abstract IModel<E> createEntityModel(@NotNull E entity);

    protected abstract IModel<?> createAdditionalModel();

    protected abstract Object getAdditionalEntity(IModel<E> additionalModel);

    // method

    /**
     * Set label width by percentage
     *
     * @param pane      probably the FormRenderer
     * @param labelSize label size by percentage. For ex. if the label needs half the space of width use 50
     */
    private void searchAndSetControlsLabelWidth(Pane pane, double labelSize) {
        if (pane instanceof GridPane) {
            if (pane.getStyleClass().stream().anyMatch(s -> s.contains("simple-"))) {
                GridPane gp = (GridPane) pane;
                if (gp.getColumnConstraints().size() == 12) {
                    double rest = 100 - labelSize;
                    for (int i = 0; i < gp.getColumnConstraints().size(); i++) {
                        if (i < 3) {
                            gp.getColumnConstraints().get(i).setPercentWidth(labelSize / 2);
                        } else {
                            gp.getColumnConstraints().get(i).setPercentWidth(rest / 10);
                        }
                    }
                }
            }
        }

        for (Node child : pane.getChildren()) {
            if (child instanceof Pane) {
                searchAndSetControlsLabelWidth((Pane) child, labelSize);
            }
        }
    }

    ViewContainer viewContainer = ViewContainer.getContainer();

    private void postEntity() {
        postForm.persist();
        E postEntity = emptyModel.exportEntity();

        getEntityController().postEntity(postEntity);
        viewContainer.getEntitiesSearchableButtonPane().getRefreshButton().fire();
    }

    private void putEntity() {
        editablePutForm.persist();
        E putEntity = entityModel.exportEntity();

        getEntityController().putEntity(putEntity);
        viewContainer.getEntitiesSearchableButtonPane().getRefreshButton().fire();
    }

    private void resetEntity() {
        editablePutForm.reset();
    }

    private void deleteEntity() {
        E entity = entityModel.exportEntity();
        getEntityController().deleteEntity(entity.getID());
        viewContainer.getEntitiesSearchableButtonPane().getRefreshButton().fire();
    }

    private void putAdditionalEntity() {
        E entity = (E) getAdditionalEntity(additionalModel);
        getEntityController().putAdditionalEntity(entity, entityModel.exportEntity().getID());
        viewContainer.getEntitiesSearchableButtonPane().getRefreshButton().fire();
    }

    private void putAdditionalEntityDelete() {
        E entity = (E) getAdditionalEntity(additionalDeleteModel);
        getEntityController().putAdditionalDeleteEntity(entity, entityModel.exportEntity().getID());
        viewContainer.getEntitiesSearchableButtonPane().getRefreshButton().fire();
    }

    // get

    /**
     * Gets post pane view of post form.
     *
     * @return post pane view of post form
     */
    public Pane getPostView() {
        VBox postPane = new VBox();

        emptyModel = createEmptyModel();
        postForm = createPostForm(emptyModel);

        Pane postFormPane = createPostPane(postForm);
        postPane.getChildren().addAll(postFormPane);

        searchAndSetControlsLabelWidth(postFormPane, 50);

        I18N i18N = I18N.getLocalizationTool();
        Pane postButtonPane = getSaveButtonPane(i18N.createStringBinding("form.post-button"), this::postEntity);
        Button b = (Button) postButtonPane.getChildren().get(0);
        b.disableProperty().bind(postForm.persistableProperty().not());

        postPane.getChildren().addAll(postButtonPane);

        ScrollPane postScrollPane = new ScrollPane(postPane);
        postScrollPane.setHbarPolicy(ScrollPane.ScrollBarPolicy.NEVER);
        postPane.prefWidthProperty().bind(postScrollPane.widthProperty());

        postScrollPane.getStyleClass().addAll("pane-primary-alternative");

        return new VBox(postScrollPane);
    }

    /**
     * Gets put pane view of post form.
     *
     * @return post pane view of post form
     */
    public Pane getPutView(@NotNull E entity) {
        VBox putPane = new VBox();

        entityModel = createEntityModel(entity);
        additionalModel = createEmptyModel();
        additionalDeleteModel = createEntityModel(entity);

        editablePutForm = createEditablePutForm(entityModel);
        additionalPutForm = createAdditionalPutForm(additionalModel);
        additionalPutDeleteForm = createAdditionalDeletePutForm(additionalDeleteModel);

        Pane editablePutFormPane = createEditablePutPane(editablePutForm);
        Pane nonEditablePutFormPane = createNonEditablePutPane(additionalPutForm);
        Pane additionalPutDeleteFormPane = createNonEditableDeletePutPane(additionalPutDeleteForm);

        putPane.getChildren().addAll(editablePutFormPane);

        I18N i18N = I18N.getLocalizationTool();

        // :)

        Pane putButtonPane = getSaveButtonPane(i18N.createStringBinding("form.put-button"), this::putEntity);
        Button b = (Button) putButtonPane.getChildren().get(0);
        b.disableProperty().bind(editablePutForm.persistableProperty().not());

        Pane deleteButtonPane = getSaveButtonPane(i18N.createStringBinding("form.delete-button"), this::deleteEntity);
        if (entity instanceof StudentsSubject)
            deleteButtonPane.disableProperty().bind(new SimpleBooleanProperty(true));

        Pane resetButtonPane = getSaveButtonPane(i18N.createStringBinding("form.reset-button"), this::resetEntity);
        b = (Button) resetButtonPane.getChildren().get(0);
        b.disableProperty().bind(editablePutForm.changedProperty().not());

        // :(

        HBox buttons = new HBox();
        buttons.setAlignment(Pos.CENTER);
        buttons.getChildren().addAll(resetButtonPane, putButtonPane, deleteButtonPane);
        putPane.getChildren().addAll(buttons);

        // :(

        if (nonEditablePutFormPane != null) {
            Pane additionalPutButtonPane = getSaveButtonPane(i18N.createStringBinding("form.additional.put-button"),
                    this::putAdditionalEntity);
            b = (Button) additionalPutButtonPane.getChildren().get(0);
            b.disableProperty().bind(additionalPutForm.persistableProperty().not());

            Pane additionalPutButtonDeletePane = getSaveButtonPane(i18N.createStringBinding("form.additional" +
                            ".put-delete-button"),
                    this::putAdditionalEntityDelete);
            b = (Button) additionalPutButtonDeletePane.getChildren().get(0);
            b.disableProperty().bind(additionalPutDeleteForm.persistableProperty().not());

            putPane.getChildren().addAll(nonEditablePutFormPane, additionalPutButtonPane, additionalPutDeleteFormPane
                    , additionalPutButtonDeletePane);
        }

        ScrollPane putScrollPane = new ScrollPane(putPane);
        putScrollPane.setHbarPolicy(ScrollPane.ScrollBarPolicy.NEVER);
        putPane.prefWidthProperty().bind(putScrollPane.widthProperty());

        putScrollPane.getStyleClass().addAll("pane-primary-alternative");
        searchAndSetControlsLabelWidth(putPane, 50);

        return new VBox(putScrollPane);
    }

    /**
     * Gets buttons pane.
     *
     * @param buttonText button text
     * @param onClick onClick event
     * @return buttons pane
     */
    private Pane getSaveButtonPane(StringBinding buttonText, Runnable onClick) {
        Button saveButton = new Button();
        saveButton.textProperty().bind(buttonText);

        VBox buttonPane = new VBox();
        buttonPane.getChildren().add(saveButton);

        buttonPane.setAlignment(Pos.CENTER);

        saveButton.setOnAction(x -> {
            onClick.run();
        });

        saveButton.getStyleClass().addAll("btn-custom-secondary");
        saveButton.getStyleClass().addAll("middle");

        saveButton.minHeightProperty().bind(new SimpleIntegerProperty(BUTTON_HEIGHT));
        saveButton.minWidthProperty().bind(new SimpleIntegerProperty(BUTTON_WIDTH));

        return buttonPane;
    }
}
