package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nform;

import com.dlsc.formsfx.model.structure.Field;
import com.dlsc.formsfx.model.structure.Form;
import com.dlsc.formsfx.model.structure.Group;
import com.dlsc.formsfx.model.structure.SingleSelectionField;
import com.dlsc.formsfx.view.renderer.FormRenderer;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Absence;
import cz.zcu.fav.kiv.mjakubas.saf.entity.ScheduleActionDate;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Student;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.AEntityController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.AbsenceModel;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.IModel;
import javafx.scene.layout.Pane;
import org.jetbrains.annotations.NotNull;

/**
 * Represent all possible forms of {@link Absence} entity.
 */
public class AbsenceForm extends AForm<Absence> {

    @Override
    protected AEntityController<?> getEntityController() {
        return EntitiesController.getEntitiesController().getAbsenceEntityController();
    }

    @Override
    protected Form createPostForm(IModel<Absence> entityModel) {
        AbsenceModel model = (AbsenceModel) entityModel;
        SingleSelectionField<Student> allStudentsField =
                Field.ofSingleSelectionType(model.allStudentsProperty())
                        .label("form.label.students-all")
                        .required("form.required");
        model.selectedStudentProperty().bind(allStudentsField.selectionProperty());
        SingleSelectionField<ScheduleActionDate> allScheduleActionDates =
                Field.ofSingleSelectionType(model.allScheduleActionDatesProperty())
                        .label("form.label.schedule-action-dates-all")
                        .required("form.required");
        model.selectedScheduleActionDateProperty().bind(allScheduleActionDates.selectionProperty());

        return Form.of(
                Group.of(
                        allStudentsField,
                        allScheduleActionDates
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createPostPane(Form postForm) {
        return new FormRenderer(postForm);
    }

    @Override
    protected Form createEditablePutForm(IModel<Absence> entityModel) {
        AbsenceModel model = (AbsenceModel) entityModel;

        SingleSelectionField<Student> allStudentsField =
                Field.ofSingleSelectionType(model.allStudentsProperty(),
                                model.allStudentsProperty().indexOf(model.selectedStudentProperty().getValue()))
                        .label("form.label.students-all")
                        .required("form.required");
        model.selectedStudentProperty().bind(allStudentsField.selectionProperty());

        SingleSelectionField<ScheduleActionDate> allScheduleActionDates =
                Field.ofSingleSelectionType(model.allScheduleActionDatesProperty(),
                                model.allScheduleActionDatesProperty().indexOf(model.selectedScheduleActionDateProperty().getValue()))
                        .label("form.label.schedule-action-dates-all")
                        .required("form.required");
        model.selectedScheduleActionDateProperty().bind(allScheduleActionDates.selectionProperty());

        return Form.of(
                Group.of(
                        Field.ofIntegerType(model.absenceIDProperty())
                                .label("form.label.id")
                                .editable(false),
                        allStudentsField,
                        allScheduleActionDates
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createEditablePutPane(Form editablePutForm) {
        return new FormRenderer(editablePutForm);
    }

    @Override
    protected Form createAdditionalPutForm(IModel<?> entityModel) {
        return null;
    }

    @Override
    protected Pane createNonEditablePutPane(Form nonEditablePutForm) {
        return null;
    }

    @Override
    protected Form createAdditionalDeletePutForm(IModel<?> entityModel) {
        return null;
    }

    @Override
    protected Pane createNonEditableDeletePutPane(Form nonEditablePutForm) {
        return null;
    }

    @Override
    protected IModel<Absence> createEmptyModel() {
        return new AbsenceModel();
    }

    @Override
    protected IModel<Absence> createEntityModel(@NotNull Absence entity) {
        IModel<Absence> absenceModel = new AbsenceModel();
        absenceModel.importEntity(entity);
        return absenceModel;
    }

    @Override
    protected IModel<?> createAdditionalModel() {
        return null;
    }

    @Override
    protected Object getAdditionalEntity(IModel<Absence> additionalModel) {
        return null;
    }
}
