package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nform;

import com.dlsc.formsfx.model.structure.*;
import com.dlsc.formsfx.model.validators.IntegerRangeValidator;
import com.dlsc.formsfx.view.renderer.FormRenderer;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Building;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Room;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.AEntityController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.BuildingModel;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.IModel;
import javafx.scene.layout.Pane;
import org.jetbrains.annotations.NotNull;

/**
 * Represent all possible forms of {@link Building} entity.
 */
public class BuildingForm extends AForm<Building> {

    @Override
    protected AEntityController<?> getEntityController() {
        return EntitiesController.getEntitiesController().getBuildingEntityController();
    }

    @Override
    protected Form createPostForm(IModel<Building> entityModel) {
        BuildingModel model = (BuildingModel) entityModel;
        return Form.of(
                Group.of(
                        Field.ofStringType(model.buildingNameProperty())
                                .label("form.label.building-name")
                                .required("form.required")
                                .placeholder("form.placeholder.building-name")
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createPostPane(Form postForm) {
        return new FormRenderer(postForm);
    }

    @Override
    protected Form createEditablePutForm(IModel<Building> entityModel) {
        BuildingModel model = (BuildingModel) entityModel;
        return Form.of(
                Group.of(
                        Field.ofIntegerType(model.buildingIDProperty())
                                .label("form.label.id")
                                .editable(false),
                        Field.ofStringType(model.buildingNameProperty())
                                .label("form.label.building-name")
                                .required("form.required")
                                .placeholder("form.placeholder.building-name")
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createEditablePutPane(Form editablePutForm) {
        return new FormRenderer(editablePutForm);
    }

    @Override
    protected Form createAdditionalPutForm(IModel<?> entityModel) {
        return null;
    }


    @Override
    protected Pane createNonEditablePutPane(Form nonEditablePutForm) {
        return null;
    }

    @Override
    protected Form createAdditionalDeletePutForm(IModel<?> entityModel) {
        return null;
    }

    @Override
    protected Pane createNonEditableDeletePutPane(Form nonEditablePutForm) {
        return null;
    }

    @Override
    protected IModel<Building> createEmptyModel() {
        return new BuildingModel();
    }

    @Override
    protected IModel<Building> createEntityModel(@NotNull Building entity) {
        IModel<Building> buildingModel = new BuildingModel();
        buildingModel.importEntity(entity);
        return buildingModel;
    }

    @Override
    protected IModel<?> createAdditionalModel() {
        return null;
    }

    @Override
    protected Object getAdditionalEntity(IModel<Building> additionalModel) {
        return null;
    }

    private Group[] createRooms(Room[] rooms) {
        Group[] groups = new Group[rooms.length];
        for (int i = 0; i < rooms.length; i++) {
            groups[i] = Group.of(
                    Field.ofIntegerType(rooms[i].getID())
                            .label("form.label.id")
                            .editable(false),
                    Field.ofStringType(rooms[i].getRoomName())
                            .label("form.label.room-name")
                            .required("form.required")
                            .placeholder("form.placeholder.room-name")
                            .editable(false),
                    Field.ofIntegerType(rooms[i].getCapacity())
                            .label("form.label.capacity")
                            .required("form.required")
                            .placeholder("form.placeholder.capacity")
                            .validate(IntegerRangeValidator.atLeast(1, "form.validator.positive-value"))
                            .editable(false)
            );
        }
        return groups;
    }
}
