package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nform;

import com.dlsc.formsfx.model.structure.Field;
import com.dlsc.formsfx.model.structure.Form;
import com.dlsc.formsfx.model.structure.Group;
import com.dlsc.formsfx.model.structure.SingleSelectionField;
import com.dlsc.formsfx.model.validators.RegexValidator;
import com.dlsc.formsfx.model.validators.StringLengthValidator;
import com.dlsc.formsfx.view.renderer.FormRenderer;
import cz.zcu.fav.kiv.mjakubas.saf.entity.SchoolClass;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Student;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Subject;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.AEntityController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.IModel;
import cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel.StudentModel;
import javafx.scene.layout.Pane;
import org.jetbrains.annotations.NotNull;

/**
 * Represent all possible forms of {@link Student} entity.
 */
public class StudentForm extends AForm<Student> {
    @Override
    protected AEntityController<?> getEntityController() {
        return EntitiesController.getEntitiesController().getStudentEntityController();
    }

    @Override
    protected Form createPostForm(IModel<Student> entityModel) {
        StudentModel model = (StudentModel) entityModel;
        SingleSelectionField<SchoolClass> allClassesField =
                Field.ofSingleSelectionType(model.allClassesProperty())
                        .label("form.label.classes-all")
                        .required("form.required");
        model.selectedClassProperty().bind(allClassesField.selectionProperty());

        return Form.of(
                Group.of(
                        Field.ofStringType(model.firstNameProperty())
                                .label("form.label.first-name")
                                .required("form.required")
                                .placeholder("form.placeholder.first-name"),
                        Field.ofStringType(model.lastNameProperty())
                                .label("form.label.last-name")
                                .required("form.required")
                                .placeholder("form.placeholder.last-name"),
                        Field.ofDate(model.birthDateProperty())
                                .label("form.label.birthdate")
                                .required("form.required")
                                .placeholder("form.placeholder.old-date"),
                        Field.ofStringType(model.residenceProperty())
                                .label("form.label.residence")
                                .required("form.required")
                                .placeholder("form.placeholder.residence"),
                        Field.ofStringType(model.phoneProperty())
                                .label("form.label.phone")
                                .required("form.required")
                                .placeholder("form.placeholder.phone")
                                .validate(
                                        StringLengthValidator.exactly(9, "form.validator.phone"),
                                        RegexValidator.forPattern("\\d*", "form.validator.digits")
                                ),
                        Field.ofStringType(model.emailProperty())
                                .label("form.label.email")
                                .required("form.required")
                                .placeholder("form.placeholder.email")
                                .validate(
                                        RegexValidator.forEmail("form.validator.email")
                                ),
                        allClassesField
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createPostPane(Form postForm) {
        return new FormRenderer(postForm);
    }

    @Override
    protected Form createEditablePutForm(IModel<Student> entityModel) {
        StudentModel model = (StudentModel) entityModel;
        SingleSelectionField<SchoolClass> allClassesField =
                Field.ofSingleSelectionType(model.allClassesProperty(),
                                model.allClassesProperty().indexOf(model.selectedClassProperty().getValue()))
                        .label("form.label.classes-all")
                        .required("form.required");
        model.selectedClassProperty().bind(allClassesField.selectionProperty());

        return Form.of(
                Group.of(
                        Field.ofIntegerType(model.idStudentsProperty())
                                .label("form.label.id")
                                .editable(false),
                        Field.ofStringType(model.firstNameProperty())
                                .label("form.label.first-name")
                                .required("form.required")
                                .placeholder("form.placeholder.first-name"),
                        Field.ofStringType(model.lastNameProperty())
                                .label("form.label.last-name")
                                .required("form.required")
                                .placeholder("form.placeholder.last-name"),
                        Field.ofDate(model.birthDateProperty())
                                .label("form.label.birthdate")
                                .required("form.required")
                                .placeholder("form.placeholder.old-date"),
                        Field.ofStringType(model.residenceProperty())
                                .label("form.label.residence")
                                .required("form.required")
                                .placeholder("form.placeholder.residence"),
                        Field.ofStringType(model.phoneProperty())
                                .label("form.label.phone")
                                .required("form.required")
                                .placeholder("form.placeholder.phone")
                                .validate(
                                        StringLengthValidator.exactly(9, "form.validator.phone"),
                                        RegexValidator.forPattern("\\d*", "form.validator.digits")
                                ),
                        Field.ofStringType(model.emailProperty())
                                .label("form.label.email")
                                .required("form.required")
                                .placeholder("form.placeholder.email")
                                .validate(
                                        RegexValidator.forEmail("form.validator.email")
                                ),
                        allClassesField
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createEditablePutPane(Form editablePutForm) {
        return new FormRenderer(editablePutForm);
    }

    @Override
    protected Form createAdditionalPutForm(IModel<?> entityModel) {
        StudentModel model = (StudentModel) entityModel;
        SingleSelectionField<Subject> allSubjectListsField =
                Field.ofSingleSelectionType(model.allSubjectsProperty())
                        .label("form.label.subjects-all")
                        .required("form.required");
        model.selectedSubjectsProperty().bind(allSubjectListsField.selectionProperty());

        return Form.of(
                Group.of(
                        allSubjectListsField
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }


    @Override
    protected Pane createNonEditablePutPane(Form nonEditablePutForm) {
        return new FormRenderer(nonEditablePutForm);
    }

    @Override
    protected Form createAdditionalDeletePutForm(IModel<?> entityModel) {
        StudentModel model = (StudentModel) entityModel;
        SingleSelectionField<Subject> allSubjectListsField =
                Field.ofSingleSelectionType(model.allTeacherSubjectsProperty())
                        .label("form.label.subjects-all")
                        .required("form.required");
        model.selectedSubjectsProperty().bind(allSubjectListsField.selectionProperty());

        return Form.of(
                Group.of(
                        allSubjectListsField
                )
        ).i18n(I18N.getLocalizationTool().getResourceBundleService());
    }

    @Override
    protected Pane createNonEditableDeletePutPane(Form nonEditablePutForm) {
        return new FormRenderer(nonEditablePutForm);
    }

    @Override
    protected IModel<Student> createEmptyModel() {
        return new StudentModel();
    }

    @Override
    protected IModel<Student> createEntityModel(@NotNull Student entity) {
        IModel<Student> studentModel = new StudentModel();
        studentModel.importEntity(entity);
        return studentModel;
    }

    @Override
    protected IModel<?> createAdditionalModel() {
        return null;
    }

    @Override
    protected Object getAdditionalEntity(IModel<Student> additionalModel) {
        StudentModel model = (StudentModel) additionalModel;
        return model.selectedSubjectsProperty().getValue();
    }
}
