package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel;

import cz.zcu.fav.kiv.mjakubas.saf.entity.Absence;
import cz.zcu.fav.kiv.mjakubas.saf.entity.ScheduleActionDate;
import cz.zcu.fav.kiv.mjakubas.saf.entity.Student;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.FetchException;
import javafx.beans.property.*;
import javafx.collections.FXCollections;

import java.util.List;

/**
 * Represents a model object of an absence entity.
 */
public class AbsenceModel implements IModel<Absence> {

    private final IntegerProperty absenceID = new SimpleIntegerProperty();
    private final ListProperty<Student> allStudents = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ListProperty<ScheduleActionDate> allScheduleActionDates = new SimpleListProperty<>(FXCollections.observableArrayList());

    private final ObjectProperty<Student> selectedStudent = new SimpleObjectProperty<>();
    private final ObjectProperty<ScheduleActionDate> selectedScheduleActionDate = new SimpleObjectProperty<>();

    // constructor

    public AbsenceModel() {
        makeAdditionalRequests();
    }

    // override

    @Override
    public void importEntity(Absence entity) {
        absenceID.set(entity.getID());
        selectedStudent.set(entity.getStudent());
        selectedScheduleActionDate.set(entity.getScheduleactionsdate());
    }

    @Override
    public Absence exportEntity() {
        Absence absence = new Absence();
        absence.setIdAbsences(absenceID.get());
        absence.setStudent(selectedStudent.getValue());
        absence.setScheduleactionsdate(selectedScheduleActionDate.getValue());
        return absence;
    }

    @Override
    public void fillAdditionalEntities() throws FetchException {
        EntitiesController entitiesController = EntitiesController.getEntitiesController();

        List<Student> studentList =
                entitiesController.getStudentEntityController().getAllFetchedEntities();
        List<ScheduleActionDate> scheduleActionDateList =
                entitiesController.getScheduleActionDateEntityController().getAllFetchedEntities();

        allStudents.addAll(studentList);
        allScheduleActionDates.addAll(scheduleActionDateList);
    }

    // get

    /**
     * Gets absence entity id.
     *
     * @return absence entity id
     */
    public IntegerProperty absenceIDProperty() {
        return absenceID;
    }

    /**
     * Gets list of all students.
     *
     * @return list of all students
     */
    public ListProperty<Student> allStudentsProperty() {
        return allStudents;
    }

    /**
     * Gets list of all schedule action dates.
     *
     * @return all schedule action dates
     */
    public ListProperty<ScheduleActionDate> allScheduleActionDatesProperty() {
        return allScheduleActionDates;
    }

    /**
     * Gets selected student entity.
     *
     * @return selected student entity
     */
    public ObjectProperty<Student> selectedStudentProperty() {
        return selectedStudent;
    }

    /**
     * Gets selected schedule action date.
     *
     * @return selected schedule action date
     */
    public ObjectProperty<ScheduleActionDate> selectedScheduleActionDateProperty() {
        return selectedScheduleActionDate;
    }
}
