package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel;

import cz.zcu.fav.kiv.mjakubas.saf.entity.ScheduleAction;
import cz.zcu.fav.kiv.mjakubas.saf.entity.ScheduleActionDate;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.FetchException;
import javafx.beans.property.*;
import javafx.collections.FXCollections;

import java.time.LocalDate;
import java.util.List;

/**
 * Represents a model object of a schedule action date entity.
 */
public class ScheduleActionDateModel implements IModel<ScheduleActionDate> {

    private final IntegerProperty scheduleActionDateID = new SimpleIntegerProperty(0);
    private final ObjectProperty<LocalDate> date = new SimpleObjectProperty<>();
    private final StringProperty theme = new SimpleStringProperty("");
    private final ListProperty<ScheduleAction> allScheduleActions = new SimpleListProperty<>(FXCollections.observableArrayList());

    private final ObjectProperty<ScheduleAction> selectedScheduleAction = new SimpleObjectProperty<>();

    public ScheduleActionDateModel() {
        makeAdditionalRequests();
    }

    // override

    @Override
    public void importEntity(ScheduleActionDate entity) {
        scheduleActionDateID.set(entity.getID());
        date.set(LocalDate.parse(entity.getDate()));
        theme.set(entity.getTheme());
        selectedScheduleAction.set(entity.getScheduleaction());
    }

    @Override
    public ScheduleActionDate exportEntity() {
        ScheduleActionDate scheduleActionDate = new ScheduleActionDate();
        scheduleActionDate.setIdScheduleactionsdates(scheduleActionDateID.getValue());
        scheduleActionDate.setDate(date.getValue().toString());
        scheduleActionDate.setTheme(theme.getValue());
        scheduleActionDate.setScheduleaction(selectedScheduleAction.getValue());
        return scheduleActionDate;
    }

    @Override
    public void fillAdditionalEntities() throws FetchException {
        EntitiesController entitiesController = EntitiesController.getEntitiesController();

        List<ScheduleAction> scheduleActionList =
                entitiesController.getScheduleActionEntityController().getAllFetchedEntities();

        allScheduleActions.addAll(scheduleActionList);
    }

    // get

    /**
     * Gets schedule action date entity id.
     *
     * @return schedule action date entity id
     */
    public IntegerProperty scheduleActionDateIDProperty() {
        return scheduleActionDateID;
    }

    /**
     * Gets schedule action date entity date.
     *
     * @return schedule action date entity date
     */
    public ObjectProperty<LocalDate> dateProperty() {
        return date;
    }

    /**
     * Gets schedule action date theme.
     *
     * @return schedule action date theme
     */
    public StringProperty themeProperty() {
        return theme;
    }

    /**
     * Gets list of all schedule actions entities.
     *
     * @return list of all schedule actions entities
     */
    public ListProperty<ScheduleAction> allScheduleActionsProperty() {
        return allScheduleActions;
    }

    /**
     * Gets selected schedule action entity.
     *
     * @return selected schedule action entity
     */
    public ObjectProperty<ScheduleAction> selectedScheduleActionProperty() {
        return selectedScheduleAction;
    }
}
