package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel;

import cz.zcu.fav.kiv.mjakubas.saf.entity.*;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.FetchException;
import javafx.beans.property.*;
import javafx.collections.FXCollections;

import java.util.List;

/**
 * Represents a model object of a schedule action entity.
 */
public class ScheduleActionModel implements IModel<ScheduleAction> {
    private final IntegerProperty scheduleActionID = new SimpleIntegerProperty(0);
    private final ListProperty<Room> allRooms = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ListProperty<Subject> allSubjects = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ListProperty<SchoolDay> allSchoolDays = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ListProperty<SchoolHour> allSchoolHours = new SimpleListProperty<>(FXCollections.observableArrayList());

    private final ObjectProperty<Room> selectedRoom = new SimpleObjectProperty<>();
    private final ObjectProperty<Subject> selectedSubject = new SimpleObjectProperty<>();
    private final ObjectProperty<SchoolDay> selectedSchoolDay = new SimpleObjectProperty<>();
    private final ObjectProperty<SchoolHour> selectedSchoolHour = new SimpleObjectProperty<>();

    public ScheduleActionModel() {
        makeAdditionalRequests();
    }

    // override

    @Override
    public void importEntity(ScheduleAction entity) {
        this.scheduleActionID.set(entity.getID());
        this.selectedRoom.set(entity.getRoom());
        this.selectedSubject.set(entity.getSubject());
        this.selectedSchoolDay.set(entity.getSchoolday());
        this.selectedSchoolHour.set(entity.getSchoolhour());
    }

    @Override
    public ScheduleAction exportEntity() {
        ScheduleAction scheduleAction = new ScheduleAction();
        scheduleAction.setIdScheduleactions(scheduleActionID.getValue());
        scheduleAction.setRoom(selectedRoom.getValue());
        scheduleAction.setSubject(selectedSubject.getValue());
        scheduleAction.setSchoolhour(selectedSchoolHour.getValue());
        scheduleAction.setSchoolday(selectedSchoolDay.getValue());
        return scheduleAction;
    }

    @Override
    public void fillAdditionalEntities() throws FetchException {
        EntitiesController entitiesController = EntitiesController.getEntitiesController();

        List<Room> roomList =
                entitiesController.getRoomEntityController().getAllFetchedEntities();
        List<Subject> subjectList =
                entitiesController.getSubjectEntityController().getAllFetchedEntities();
        List<SchoolDay> schoolDayList =
                entitiesController.getSchoolDayEntityController().getAllFetchedEntities();
        List<SchoolHour> schoolHourList =
                entitiesController.getSchoolHourEntityController().getAllFetchedEntities();

        allRooms.addAll(roomList);
        allSubjects.addAll(subjectList);
        allSchoolDays.addAll(schoolDayList);
        allSchoolHours.addAll(schoolHourList);
    }

    // get

    /**
     * Gets schedule action entity id.
     *
     * @return schedule action entity id
     */
    public IntegerProperty scheduleActionIDProperty() {
        return scheduleActionID;
    }

    /**
     * Gets list of all rooms entities.
     *
     * @return list of all rooms entities
     */
    public ListProperty<Room> allRoomsProperty() {
        return allRooms;
    }

    /**
     * Gets list of all subjects entities.
     *
     * @return list of all subjects entities
     */
    public ListProperty<Subject> allSubjectsProperty() {
        return allSubjects;
    }

    /**
     * Gets list of all school days entities.
     *
     * @return list of all school days entities
     */
    public ListProperty<SchoolDay> allSchoolDaysProperty() {
        return allSchoolDays;
    }

    /**
     * Gets list of all school hours entities.
     *
     * @return list of all school hours entities
     */
    public ListProperty<SchoolHour> allSchoolHoursProperty() {
        return allSchoolHours;
    }

    /**
     * Gets selected room entity.
     *
     * @return selected room entity
     */
    public ObjectProperty<Room> selectedRoomProperty() {
        return selectedRoom;
    }

    /**
     * Gets selected subject entity.
     *
     * @return selected subject entity
     */
    public ObjectProperty<Subject> selectedSubjectProperty() {
        return selectedSubject;
    }

    /**
     * Gets selected school day entity.
     *
     * @return selected school day entity
     */
    public ObjectProperty<SchoolDay> selectedSchoolDayProperty() {
        return selectedSchoolDay;
    }

    /**
     * Gets selected school hour entity.
     *
     * @return selected school hour entity
     */
    public ObjectProperty<SchoolHour> selectedSchoolHourProperty() {
        return selectedSchoolHour;
    }
}
