package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel;

import cz.zcu.fav.kiv.mjakubas.saf.entity.SchoolHour;
import javafx.beans.property.IntegerProperty;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.beans.property.SimpleStringProperty;
import javafx.beans.property.StringProperty;

/**
 * Represents a model object of a school hour entity.
 */
public class SchoolHourModel implements IModel<SchoolHour> {
    private final IntegerProperty schoolHourID = new SimpleIntegerProperty(0);
    private final StringProperty schoolHourName = new SimpleStringProperty("");
    private final StringProperty schoolHourBegin = new SimpleStringProperty("");
    private final StringProperty schoolHourEnd = new SimpleStringProperty("");

    // override

    @Override
    public void importEntity(SchoolHour entity) {
        schoolHourID.set(entity.getID());
        schoolHourName.set(entity.getSchoolhourName());
        schoolHourBegin.set(entity.getSchoolhourBegin().substring(0, entity.getSchoolhourBegin().length() - 3));
        schoolHourEnd.set(entity.getSchoolhourEnd().substring(0, entity.getSchoolhourBegin().length() - 3));
    }

    @Override
    public SchoolHour exportEntity() {
        return new SchoolHour(schoolHourID.getValue(), schoolHourName.getValue(),
                schoolHourBegin.getValue() + ":00", schoolHourEnd.getValue() + ":00",
                null, null);
    }

    // get

    /**
     * Gets school hour entity id.
     *
     * @return school hour entity id
     */
    public IntegerProperty schoolHourIDProperty() {
        return schoolHourID;
    }

    /**
     * Gets school hour entity name.
     *
     * @return school hour entity name
     */
    public StringProperty schoolHourNameProperty() {
        return schoolHourName;
    }

    /**
     * Gets school hour entity start hour.
     *
     * @return school hour entity start hour
     */
    public StringProperty schoolHourBeginProperty() {
        return schoolHourBegin;
    }

    /**
     * Gets school hour entity end hour.
     *
     * @return school hour entity end hour
     */
    public StringProperty schoolHourEndProperty() {
        return schoolHourEnd;
    }
}
