package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel;

import cz.zcu.fav.kiv.mjakubas.saf.entity.*;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.FetchException;
import javafx.beans.property.*;
import javafx.collections.FXCollections;

import java.time.LocalDate;
import java.util.List;

/**
 * Represents a model object of a student entity.
 */
public class StudentModel implements IModel<Student> {
    private final IntegerProperty idStudents = new SimpleIntegerProperty(0);
    private final StringProperty firstName = new SimpleStringProperty("");
    private final StringProperty lastName = new SimpleStringProperty("");
    private final ObjectProperty<LocalDate> birthDate = new SimpleObjectProperty<>();
    private final StringProperty residence = new SimpleStringProperty("");
    private final StringProperty phone = new SimpleStringProperty("");
    private final StringProperty email = new SimpleStringProperty("");
    private final ListProperty<SchoolClass> allClasses = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ObjectProperty<SchoolClass> selectedClass = new SimpleObjectProperty<>();

    private final ListProperty<Subject> allSubjects = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ObjectProperty<Subject> selectedSubjects = new SimpleObjectProperty<>();
    private final ListProperty<Subject> allTeacherSubjects = new SimpleListProperty<>(FXCollections.observableArrayList());

    public StudentModel() {
        makeAdditionalRequests();
    }

    // override

    @Override
    public void importEntity(Student entity) {
        this.idStudents.set(entity.getID());
        this.firstName.set(entity.getFirstName());
        this.lastName.set(entity.getLastName());
        this.birthDate.set(LocalDate.parse(entity.getBirthDate()));
        this.residence.set(entity.getResidence());
        this.phone.set("" + entity.getPhone());
        this.email.set(entity.getEmail());
        this.selectedClass.set(entity.getClassesEntity());
        this.allTeacherSubjects.addAll(entity.getSubjects());
    }

    @Override
    public Student exportEntity() {
        Student student = new Student(idStudents.getValue(), firstName.getValue(), lastName.getValue(),
                birthDate.getValue().toString(), residence.getValue(), Integer.parseInt(phone.getValue()),
                email.getValue(), null, null, null);
        student.setClassesEntity(selectedClass.getValue());
        return student;
    }

    @Override
    public void fillAdditionalEntities() throws FetchException {
        EntitiesController entitiesController = EntitiesController.getEntitiesController();

        List<SchoolClass> classList =
                entitiesController.getClassEntityController().getAllFetchedEntities();

        allClasses.addAll(classList);

        List<Subject> subjectList =
                entitiesController.getSubjectEntityController().getAllFetchedEntities();

        this.allSubjects.addAll(subjectList);
    }

    // get

    /**
     * Gets student entity id.
     *
     * @return student entity ids
     */
    public IntegerProperty idStudentsProperty() {
        return idStudents;
    }

    /**
     * Gets student entity first name.
     *
     * @return student entity first name
     */
    public StringProperty firstNameProperty() {
        return firstName;
    }

    /**
     * Gets student entity last name.
     *
     * @return student entity last name
     */
    public StringProperty lastNameProperty() {
        return lastName;
    }

    /**
     * Gets student entity birthdate.
     *
     * @return student entity birthdate
     */
    public ObjectProperty<LocalDate> birthDateProperty() {
        return birthDate;
    }

    /**
     * Gets student entity residence.
     *
     * @return student entity residence
     */
    public StringProperty residenceProperty() {
        return residence;
    }

    /**
     * Gets student entity phone.
     *
     * @return student entity phone
     */
    public StringProperty phoneProperty() {
        return phone;
    }

    /**
     * Gets student entity email.
     *
     * @return student entity email
     */
    public StringProperty emailProperty() {
        return email;
    }

    /**
     * Gets list of class entities.
     *
     * @return list of class entities
     */
    public ListProperty<SchoolClass> allClassesProperty() {
        return allClasses;
    }

    /**
     * Gets selected class entity.
     *
     * @return selected class entity
     */
    public ObjectProperty<SchoolClass> selectedClassProperty() {
        return selectedClass;
    }

    public ListProperty<Subject> allSubjectsProperty() {
        return allSubjects;
    }

    public ObjectProperty<Subject> selectedSubjectsProperty() {
        return selectedSubjects;
    }

    public ListProperty<Subject> allTeacherSubjectsProperty() {
        return allTeacherSubjects;
    }
}
