package cz.zcu.fav.kiv.mjakubas.saf.gui.form.nmodel;

import cz.zcu.fav.kiv.mjakubas.saf.entity.*;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.FetchException;
import javafx.beans.property.*;
import javafx.collections.FXCollections;

import java.util.List;

/**
 * Represents a model object of a subject entity.
 */
public class SubjectModel implements IModel<Subject> {

    private final IntegerProperty subjectID = new SimpleIntegerProperty(0);
    private final StringProperty subjectName = new SimpleStringProperty("");
    private final ListProperty<SubjectList> allSubjectLists = new SimpleListProperty<>(FXCollections.observableArrayList());
    private final ListProperty<Teacher> allTeachers = new SimpleListProperty<>(FXCollections.observableArrayList());

    private final ObjectProperty<SubjectList> selectedSubjectList = new SimpleObjectProperty<>();
    private final ObjectProperty<Teacher> selectedTeacher = new SimpleObjectProperty<>();

    // constructor

    public SubjectModel() {
        makeAdditionalRequests();
    }

    // override

    @Override
    public void importEntity(Subject entity) {
        this.subjectID.set(entity.getIdSubjects());
        this.subjectName.set(entity.getSubjectName());
        this.selectedSubjectList.set(entity.getSubjectlist());
        this.selectedTeacher.set(entity.getTeacher());
    }

    @Override
    public Subject exportEntity() {
        Subject subject = new Subject(subjectID.getValue(), subjectName.getValue(), null, null);
        subject.setSubjectlist(selectedSubjectList.getValue());
        subject.setTeacher(selectedTeacher.getValue());
        return subject;
    }

    @Override
    public void fillAdditionalEntities() throws FetchException {
        EntitiesController entitiesController = EntitiesController.getEntitiesController();

        List<SubjectList> subjectList =
                entitiesController.getSubjectListEntityController().getAllFetchedEntities();
        List<Teacher> teacherList =
                entitiesController.getTeacherEntityController().getAllFetchedEntities();

        this.allSubjectLists.addAll(subjectList);
        this.allTeachers.addAll(teacherList);
    }

    // get

    /**
     * Gets subject entity id.
     *
     * @return subject entity id
     */
    public IntegerProperty subjectIDProperty() {
        return subjectID;
    }

    /**
     * Gets subject entity name.
     *
     * @return subject entity name
     */
    public StringProperty subjectNameProperty() {
        return subjectName;
    }

    /**
     * Gets list of all subject list entities.
     *
     * @return list of all subject list entities
     */
    public ListProperty<SubjectList> allSubjectListsProperty() {
        return allSubjectLists;
    }

    /**
     * Gets list of all teacher entities.
     *
     * @return list of all teacher entities
     */
    public ListProperty<Teacher> allTeachersProperty() {
        return allTeachers;
    }

    /**
     * Gets selected subject list entity.
     *
     * @return selected subject list entity
     */
    public ObjectProperty<SubjectList> selectedSubjectListProperty() {
        return selectedSubjectList;
    }

    /**
     * Gets selected teacher entity.
     *
     * @return selected teacher entity
     */
    public ObjectProperty<Teacher> selectedTeacherProperty() {
        return selectedTeacher;
    }
}
