package cz.zcu.fav.kiv.mjakubas.saf.gui.menu;

import cz.zcu.fav.kiv.mjakubas.saf.gui.controller.entity.EntitiesController;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.gui.view.Importer;
import cz.zcu.fav.kiv.mjakubas.saf.gui.view.ViewContainer;
import javafx.beans.binding.StringBinding;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuItem;

import java.util.ArrayList;
import java.util.List;

/**
 * Represents a {@link Menu} GUI element implementation for controlling
 * entities.
 */
public class EntityControlsMenu extends AMenu {

    /**
     * Instantiates new class representing a {@link Menu} of content for
     * controlling entites.
     *
     * @param menuName menu name
     */
    public EntityControlsMenu(StringBinding menuName) {
        super(menuName);
    }

    @Override
    protected List<MenuItem> defineMenuItems() {
        ArrayList<MenuItem> menuItems = new ArrayList<>();

        I18N i18N = I18N.getLocalizationTool();
        menuItems.add(createEntitiesMenuItem(
                i18N.createStringBinding("app.menus.entity.import"),
                x -> importEntities()));
        menuItems.add(createEntitiesMenuItem(
                i18N.createStringBinding("app.menus.entity.refresh"),
                x -> refreshEntities()));

        return menuItems;
    }

    private MenuItem createEntitiesMenuItem(StringBinding menuItemName, EventHandler<ActionEvent> onClick) {
        MenuItem menuItem = new MenuItem();
        menuItem.textProperty().bind(menuItemName);
        menuItem.setOnAction(onClick);

        return menuItem;
    }

    private void importEntities() {
        Importer.getFileChooser().importFile();
    }

    private void refreshEntities() {
        EntitiesController.getEntitiesController().purgeFetchedData();
        ViewContainer.getContainer().getEntitiesSearchableButtonPane().getRefreshButton().fire();
    }
}
