package cz.zcu.fav.kiv.mjakubas.saf.gui.menu;

import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import javafx.beans.binding.StringBinding;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuItem;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

/**
 * Represents a {@link Menu} GUI element implementation for {@link I18N}
 * controls.
 */
public class I18NMenu extends AMenu {

    /**
     * Instantiates new class representing a {@link Menu} of content for
     * localisation tool.
     *
     * @param menuName menu name
     */
    public I18NMenu(StringBinding menuName) {
        super(menuName);
    }

    @Override
    protected List<MenuItem> defineMenuItems() {
        ArrayList<MenuItem> menuItems = new ArrayList<>();

        I18N i18N = I18N.getLocalizationTool();
        menuItems.add(createI18NMenuItem(
                i18N.createStringBinding("app.menus.i18n.czech"),
                x -> i18N.setLocale(new Locale("cs", "CZ"))));
        menuItems.add(createI18NMenuItem(
                i18N.createStringBinding("app.menus.i18n.english"),
                x -> i18N.setLocale(new Locale("en", "US"))));

        return menuItems;
    }

    private MenuItem createI18NMenuItem(StringBinding menuItemName, EventHandler<ActionEvent> onClick) {
        MenuItem menuItem = new MenuItem();
        menuItem.textProperty().bind(menuItemName);
        menuItem.setOnAction(onClick);

        return menuItem;
    }
}
