package cz.zcu.fav.kiv.mjakubas.saf.gui.view;

import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import javafx.beans.binding.StringBinding;
import javafx.geometry.Pos;
import javafx.scene.control.Button;
import javafx.scene.control.ToggleButton;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;

/**
 * {@link ASearchableButtonPane} implementation for entities searchable button pane.
 */
public class EntitiesSearchableButtonPane extends ASearchableButtonPane<ToggleButton> {

    private Button refreshButton;

    // override
    @Override
    protected StringBinding getSearchFieldPrompt() {
        return I18N.getLocalizationTool().createStringBinding("entity.prompt-search");
    }

    @Override
    protected StringBinding getEmptyButtonLabel() {
        return I18N.getLocalizationTool().createStringBinding("entity.label-empty");
    }

    @Override
    protected Pane fillOptionalPane() {
        VBox optionalPane = new VBox();

        optionalPane.getStyleClass().addAll("btn-group-vertical");

        refreshButton = addRefreshButton();
        optionalPane.getChildren().addAll(refreshButton);
        return optionalPane;
    }

    // add entity

    /**
     * Adds an entity to pane.
     *
     * @param text button text
     * @param onClick onClick event
     */
    public void addEntity(String text, Runnable onClick) {
        ToggleButton toggleButton = new ToggleButton(text);

        toggleButton.setAlignment(Pos.BASELINE_LEFT);
        toggleButton.getStyleClass().addAll("btn-custom-primary");
        toggleButton.getStyleClass().addAll("middle");

        addSearchableButton(toggleButton, onClick);
    }

    // refresh button

    private Button addRefreshButton() {
        Button refreshButton = new Button();
        refreshButton.textProperty().bind(I18N.getLocalizationTool().createStringBinding("app.menus.entity.refresh"));

        //refreshButton.getStyleClass().addAll("btn", "btn-lg", "btn-primary");
        refreshButton.getStyleClass().addAll("btn-custom-primary", "btn-lg");
        refreshButton.getStyleClass().addAll("middle");

        refreshButton.prefWidthProperty().bind(rootPane.widthProperty());

        return refreshButton;
    }

    public void setRefreshButtonAction(Runnable onClick) {
        refreshButton.setOnAction(x -> {
            onClick.run();
            categorySearchableButtonPane.getFocusButton().fire();
        });
    }


    private CategorySearchableButtonPane categorySearchableButtonPane;

    public void setReloadFunction(CategorySearchableButtonPane categoryPane) {
        this.categorySearchableButtonPane = categoryPane;
    }

    public Button getRefreshButton() {
        return refreshButton;
    }
}
