package cz.zcu.fav.kiv.mjakubas.saf.gui.view;

import com.dlsc.formsfx.model.structure.Form;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import javafx.beans.binding.*;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.scene.control.*;
import javafx.scene.layout.*;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * Represents a {@link Pane} that allows to show a various {@link Form} of entities.
 */
public class EntityFormsPane {

    private static final int MIN_NODE_HEIGHT = 50; //px

    // pane

    private final VBox rootPane = new VBox();
    private final VBox contentPane = new VBox();
    private final VBox showPane = new VBox();
    private final VBox createPane = new VBox();

    // toggle button

    private ToggleButton manipulationButtonInFocus;

    // constructor

    /**
     * Instantiates new class that represents a {@link Pane} that allows to show a various {@link Form} of entities.
     */
    public EntityFormsPane() {
        initContentPanes();

        switchContent(createPane);
        rootPane.getChildren().addAll(buildEntityManipulationPane(), contentPane);
    }

    // method

    private Pane buildEntityManipulationPane() {
        VBox rootPane = new VBox();

        HBox importPane = new HBox();
        importPane.getStyleClass().addAll("btn-group-horizontal");
        HBox formManipulationPane = new HBox();
        formManipulationPane.getStyleClass().addAll("btn-group-horizontal");

        rootPane.getChildren().addAll(importPane, formManipulationPane);

        I18N i18N = I18N.getLocalizationTool();
        importPane.getChildren().addAll(
                createManipulationButton(i18N.createStringBinding("form.upload-button"),
                        this::uploadEntities, 1)
        );


        formManipulationPane.getChildren().addAll(
                createManipulationButton(
                        I18N.getLocalizationTool().createStringBinding("form.show-button"),
                        () -> switchContent(showPane), 2
                ),
                createManipulationButton(
                        I18N.getLocalizationTool().createStringBinding("form.create-button"),
                        () -> switchContent(createPane), 2
                )
        );

        return rootPane;
    }

    private ToggleButton createManipulationButton(StringBinding nameBinding, Runnable onClick, int div) {
        ToggleButton button = new ToggleButton();
        button.textProperty().bind(nameBinding);

        //button.getStyleClass().addAll("btn-custom", "btn", "btn-lg");
        button.getStyleClass().addAll("btn-custom-secondary");
        button.getStyleClass().addAll("middle");

        NumberBinding binding = rootPane.widthProperty().divide(div);
        button.prefWidthProperty().bind(binding);

        button.minHeightProperty().bind(new SimpleIntegerProperty(MIN_NODE_HEIGHT));

        button.setOnAction(x -> {
            manipulationButtonInFocus = button;
            unFocusButtons();

            onClick.run();
        });

        manipulationButtons.add(button);
        return button;
    }

    private final List<ToggleButton> manipulationButtons = new ArrayList<>();

    private void unFocusButtons() {
        for (ToggleButton button : manipulationButtons) {
            if (button == manipulationButtonInFocus)
                continue;
            button.setSelected(false);
        }
    }

    private void initContentPanes() {
        Label info1 = new Label();
        Label info2 = new Label();

        I18N i18N = I18N.getLocalizationTool();
        info1.textProperty().bind(info2.textProperty());
        info2.textProperty().bind(i18N.createStringBinding("form.empty-label"));

        info1.getStyleClass().addAll("text-custom", "h4");
        info2.getStyleClass().addAll("text-custom", "h4");

        VBox vBox1 = new VBox(info1);
        vBox1.setAlignment(Pos.CENTER);
        vBox1.setPadding(new Insets(200, 0, 200, 0));
        showPane.getChildren().add(vBox1);

        VBox vBox2 = new VBox(info2);
        vBox2.setAlignment(Pos.CENTER);
        vBox2.setPadding(new Insets(200, 0, 200, 0));
        createPane.getChildren().add(vBox2);
    }

    // onClick

    private void switchContent(@NotNull Pane content) {
        contentPane.getChildren().clear();
        contentPane.getChildren().add(content);
    }

    private void uploadEntities() {
        Importer.getFileChooser().importFile();
    }

    // get

    /**
     * Gets entity forms as a {@link Pane}.
     *
     * @return entity forms as a {@link Pane}
     */
    public Pane getFormsPane() {
        return rootPane;
    }

    // set

    /**
     * Sets and shows show {@link Pane} of forms views.
     *
     * @param showPane show {@link Pane}
     */
    public void setAndShowShowPane(@NotNull Pane showPane) {
        this.showPane.getChildren().clear();
        this.showPane.getChildren().add(showPane);
        switchContent(this.showPane);
    }

    /**
     * Sets and shows create {@link Pane} of forms views.
     *
     * @param createPane create {@link Pane}
     */
    public void setAndShowCreatePane(@NotNull Pane createPane) {
        this.createPane.getChildren().clear();
        this.createPane.getChildren().add(createPane);
        switchContent(this.createPane);
    }
}
