package cz.zcu.fav.kiv.mjakubas.saf.gui.view;

import cz.zcu.fav.kiv.mjakubas.saf.config.ConfigManager;
import cz.zcu.fav.kiv.mjakubas.saf.gui.alert.CustomAlerts;
import cz.zcu.fav.kiv.mjakubas.saf.gui.i18n.I18N;
import cz.zcu.fav.kiv.mjakubas.saf.request.EntitiesRequests;
import cz.zcu.fav.kiv.mjakubas.saf.request.MultiPost;
import cz.zcu.fav.kiv.mjakubas.saf.request.basicrequest.exception.RequestErrorException;
import javafx.beans.property.SimpleObjectProperty;
import javafx.stage.FileChooser;
import javafx.stage.Stage;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.util.List;
import java.util.Map;

/**
 * Multi-import GUI implementation.
 */
public class Importer {
    private static final Logger L = LogManager.getLogger(Importer.class);

    private Stage parentStage;

    private FileChooser fileChooser;
    private final SimpleObjectProperty<File> lastKnownDirectoryProperty = new SimpleObjectProperty<>();

    public static final Importer INSTANCE = new Importer();

    public static Importer getFileChooser() {
        return INSTANCE;
    }

    private Importer() {
        initFileChooser();
    }

    private void initFileChooser() {
        fileChooser = new FileChooser();
        fileChooser.initialDirectoryProperty().bindBidirectional(lastKnownDirectoryProperty);
        fileChooser.titleProperty().bind(I18N.getLocalizationTool().createStringBinding("menu_importer_as_file"));
    }

    /**
     * Imports an entities file.
     */
    public void importFile() {
        File file = fileChooser.showOpenDialog(parentStage);
        if (file != null) {
            L.info("File selected for import: " + file.getAbsolutePath());
            lastKnownDirectoryProperty.set(file.getParentFile());

            try {
                String serialization = Files.readString(file.toPath());
                Map<String, List<Object>> processedEntities = MultiPost.processEntities(serialization);
                if (processedEntities == null || processedEntities.size() == 0) {
                    CustomAlerts.showErrorAlert("error.multiUpload", "error uploading all entities");
                }

                try {
                    EntitiesRequests.multiPost(ConfigManager.getManager().getRequestConfig(), processedEntities);
                } catch (RequestErrorException e) {
                    CustomAlerts.showErrorAlert("error.multiUpload", e.getMessage());
                    throw new RuntimeException(e);
                }
            } catch (IOException e) {
                CustomAlerts.showErrorAlert("unknow.error", "unknown error has happened while importing entities from" +
                        " file");
                throw new RuntimeException(e);
            }

            CustomAlerts.showInfoAlert("alert.header.post-entity", "alert.header.post-entity.ok");
        }
    }

    /**
     * Sets parent stage.
     *
     * @param parentStage parent stage.
     */
    public void setParentStage(Stage parentStage) {
        this.parentStage = parentStage;
    }
}
