package cz.zcu.fav.kiv.mjakubas.saf.io.file;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;

import java.io.IOException;
import java.nio.file.FileAlreadyExistsException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * I/O operations over any file using.
 */
public class FileIO {
    private static final Logger L = LogManager.getLogger(FileIO.class);

    /**
     * Tries to copy whole directory content to destination. If any copied file already exists does nothing.
     *
     * @param sourceDirectoryLocation      source
     * @param destinationDirectoryLocation destination
     * @throws NullPointerException if any parameter is null
     * @throws IOException          if any I/O exception happens
     */
    public static void copyDirectory(@NotNull String sourceDirectoryLocation, @NotNull String destinationDirectoryLocation) throws IOException {
        try {
            Files.walk(Paths.get(sourceDirectoryLocation)).forEach(source -> {
                Path destination = Paths.get(destinationDirectoryLocation, source.toString()
                        .substring(sourceDirectoryLocation.length()));

                try {
                    Files.copy(source, destination);
                } catch (FileAlreadyExistsException e) {
                    // implementation defined as not error
                    L.debug(e);
                } catch (IOException e) {
                    L.error(e);
                }
            });
        } catch (IOException e) {
            L.error(e);
            throw e;
        }
    }
}
