package cz.zcu.fav.kiv.mjakubas.saf.io.resource;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;

import java.io.*;
import java.net.URISyntaxException;
import java.net.URL;
import java.nio.file.*;

/**
 * I/O operations over any resources.
 */
public class ResourcesIO {

    /**
     * Gets resource from resource folder.
     *
     * @param resource resource
     * @return resource as {@link InputStream}
     * @throws IOException if any exception happens
     */
    public static InputStream getResourceInputStream(@NotNull String resource) throws IOException {
        InputStream is = ResourcesIO.class.getClassLoader().getResourceAsStream(resource);
        if (is == null)
            throw new IOException("Resource not found!");
        return is;
    }

    /**
     * Creates temporary directory.
     **/
    public static Path createTempDirectory(@NotNull String dirName, @NotNull String... resources)
            throws IOException {
        Path p = Files.createTempDirectory(dirName);
        for (String r : resources) {
            Path t = Files.createTempFile(p, "", r);
            InputStream is = getResourceInputStream(r);
            Files.write(t, is.readAllBytes());
        }
        return p;
    }
}
