package cz.zcu.fav.kiv.mjakubas.saf.parser.mapper;

import cz.zcu.fav.kiv.mjakubas.saf.parser.mapper.exception.MapperException;
import org.jetbrains.annotations.NotNull;

/**
 * Serializes objects to a serializable state. Deserializes serialization to objects.
 */
public interface IMapper {

    /**
     * Serializes objects to a string representation.
     *
     * @param entities array of objects to be serialized
     * @param <T>      target of serialization
     * @return serialized objects
     * @throws MapperException if serialization fails
     */
    public <T> String serialize(@NotNull T[] entities) throws MapperException;

    /**
     * Serializes objects to a string representation.
     *
     * @param entity object to be serialized
     * @param <T>    target of serialization
     * @return serialized objects
     * @throws MapperException if serialization fails
     */
    public <T> String serialize(@NotNull T entity) throws MapperException;

    /**
     * Deserializes serialized objects in a string format to objects.
     *
     * @param serialization serialized string
     * @param entitiesClass serialized entities object class
     * @param <T>           target of deserialization
     * @return deserialized objects
     * @throws MapperException if deserialization fails
     */
    public <T> T[] deserialize(@NotNull String serialization, @NotNull Class<T> entitiesClass) throws MapperException;

    /**
     * Deserializes only one specific entity.
     *
     * @param serialization serialization
     * @param entitiesClass entity class
     * @param <T>           entity type
     * @return deseralized entity
     * @throws MapperException if any exception happens
     */
    public <T> T deserializeOne(@NotNull String serialization, @NotNull Class<T> entitiesClass) throws MapperException;
}
