package cz.zcu.fav.kiv.mjakubas.saf.parser.mapper;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.dataformat.xml.XmlMapper;
import cz.zcu.fav.kiv.mjakubas.saf.parser.mapper.exception.MapperException;
import org.jetbrains.annotations.NotNull;

/**
 * Serializes objects to JSON. Deserializes JSON to objects.
 *
 * @see IMapper
 */
public class XMLMapper implements IMapper {

    private final XmlMapper mapper = new XmlMapper();

    {
        mapper.setSerializationInclusion(JsonInclude.Include.NON_NULL);
    }

    @Override
    public <T> String serialize(@NotNull T[] entities) throws MapperException {
        try {
            return mapper.writeValueAsString(entities);
        } catch (JsonProcessingException e) {
            throw new MapperException(e);
        }
    }

    @Override
    public <T> String serialize(@NotNull T entity) throws MapperException {
        try {
            return mapper.writeValueAsString(entity);
        } catch (JsonProcessingException e) {
            throw new MapperException(e);
        }
    }

    @Override
    public <T> T[] deserialize(@NotNull String serialization, @NotNull Class<T> entitiesClass) throws MapperException {
        if (serialization.replaceAll(" ", "").equals("")) {
            throw new MapperException("Empty string not allowed!");
        }
        try {
            return mapper.readValue(serialization, mapper.getTypeFactory().constructArrayType(entitiesClass));
        } catch (JsonProcessingException e) {
            throw new MapperException(e);
        }
    }

    @Override
    public <T> T deserializeOne(@NotNull String serialization, @NotNull Class<T> entitiesClass) throws MapperException {
        if (serialization.replaceAll(" ", "").equals("")) {
            throw new MapperException("Empty string not allowed!");
        }
        try {
            return mapper.readValue(serialization, mapper.getTypeFactory().constructType(entitiesClass));
        } catch (JsonProcessingException e) {
            throw new MapperException(e);
        }
    }
}
