package cz.zcu.fav.kiv.mjakubas.saf.parser.tokenizer;

import org.jetbrains.annotations.NotNull;

/**
 * Represents command in tokenized form.
 */
public class Token {
    private final Class<?> classToken;
    private final String stringToken;

    /**
     * Instantiates token as a {@link Class} value.
     *
     * @param classToken {@link Class} value
     */
    public Token(@NotNull Class<?> classToken) {
        this(classToken, null);
    }

    /**
     * Instantiates token as a {@link String} value.
     *
     * @param stringToken {@link String} value
     */
    public Token(@NotNull String stringToken) {
        this(null, stringToken);
    }

    private Token(Class<?> classToken, String stringToken) {
        this.classToken = classToken;
        this.stringToken = stringToken;
    }

    @Override
    public String toString() {
        String to = "Token{";
        to += (classToken == null) ? stringToken : classToken.getSimpleName();
        to += "}";
        return to;
    }

    /**
     * Gets {@link Class} value of {@link Token} or null.
     *
     * @return {@link Class} value of {@link Token} or null
     */
    public Class<?> getClassToken() {
        return classToken;
    }

    /**
     * Gets {@link String} value of {@link Token} or null.
     *
     * @return {@link String} value of {@link Token} or null
     */
    public String getStringToken() {
        return stringToken;
    }
}
