package cz.zcu.fav.kiv.mjakubas.saf;

import cz.zcu.fav.kiv.mjakubas.saf.config.configs.*;
import cz.zcu.fav.kiv.mjakubas.saf.entity.*;
import cz.zcu.fav.kiv.mjakubas.saf.parser.mapper.*;
import cz.zcu.fav.kiv.mjakubas.saf.request.*;
import org.junit.jupiter.api.*;

import java.util.*;

public class TestEntitiesPosterTest {

    private static final RequestConfig C = RequestConfigTestConfigTest.getTestConfig();

    public static int[] postTestEntities(ASimpleEntity[] entities, Class<?> entityClass, String endPoint) throws Exception {
        EntitiesRequestResult[] r = EntitiesRequests.post(C, endPoint, entities);
        int[] ids = new int[r.length];
        JSONMapper mapper = new JSONMapper();
        for (int i = 0; i < ids.length; i++) {
            ASimpleEntity e = (ASimpleEntity) mapper.deserializeOne(r[i].getHttpResponseResult().getResponse(), entityClass);
            ids[i] = e.getID();
        }

        return ids;
    }

    public static void deleteTestEntities(int[][] ids, String... requests) throws Exception {
        for (int i = 0; i < ids.length; i++) {
            int[] row = ids[i];
            for (int id : row) {
                EntitiesRequests.delete(C, requests[i] + RequestConfig.ID_QUERY + "/" + id);
            }
        }
    }

    public static int[][] postTestAbsences() throws Exception {
        int[][] multipleSIds = postTestStudents();
        int[][] multipleSchIds = postTestScheduleActionsDates();

        Absence[] e = EntitiesTestLoaderTest.loadAbsences();

        e[0].getStudent().setIdStudents(multipleSIds[0][0]);
        e[0].getScheduleactionsdate().setIdScheduleactionsdates(multipleSchIds[0][0]);

        e[1].getStudent().setIdStudents(multipleSIds[0][1]);
        e[1].getScheduleactionsdate().setIdScheduleactionsdates(multipleSchIds[0][1]);

        int[] ids = postTestEntities(e, Absence.class, RequestConfig.ABSENCE_ENTITIES_QUERY);

        return new int[][]{
                ids, multipleSIds[0], multipleSIds[1], multipleSIds[2], multipleSIds[3], multipleSIds[4],
                multipleSchIds[0], multipleSchIds[1], multipleSchIds[2], multipleSchIds[3], multipleSchIds[4],
                multipleSchIds[5], multipleSchIds[6], multipleSchIds[7], multipleSchIds[8]};
    }

    public static int[][] postTestBuildings() throws Exception {
        ASimpleEntity[] e = EntitiesTestLoaderTest.loadBuildings();
        int[] ids = postTestEntities(e, Building.class, RequestConfig.BUILDING_ENTITIES_QUERY);
        return new int[][]{ids};
    }

    public static int[][] postTestClasses() throws Exception {
        int[] tIds = postTestTeachers()[0];
        int[][] multipleRIds = postTestRooms();
        int[] rIds = multipleRIds[0];

        SchoolClass[] e = EntitiesTestLoaderTest.loadClasses();
        e[0].getRoom().setIdRooms(rIds[0]);
        e[1].getRoom().setIdRooms(rIds[1]);

        e[0].getTeacher().setIdTeachers(tIds[0]);
        e[1].getTeacher().setIdTeachers(tIds[1]);

        int[] ids = postTestEntities(e, SchoolClass.class, RequestConfig.CLASSES_ENTITIES_QUERY);

        return new int[][]{ids, tIds, multipleRIds[0], multipleRIds[1]};
    }

    public static int[][] postTestEvaluations() throws Exception {
        int[][] studentsIds = postTestStudents();
        int[][] subjectsIds = postTestSubjects();

        Subject ts = EntitiesTestLoaderTest.loadSubjects()[0];
        ts.setSubjectName("");

        for (int tId : studentsIds[1]) {
            String ps = "/";
            String path = RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ID_QUERY + ps + tId
                    + RequestConfig.SUBJECT_QUERY + RequestConfig.ADD_QUERY;
            for (int sId : subjectsIds[0]) {
                ts.setIdSubjects(sId);
                EntitiesRequestResult r = EntitiesRequests.put(C, path, ts);
            }
        }

        for (int tId : studentsIds[0]) {
            String ps = "/";
            String path = RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + ps + tId
                    + RequestConfig.SUBJECT_QUERY + RequestConfig.ADD_QUERY;
            for (int sId : subjectsIds[0]) {
                ts.setIdSubjects(sId);
                EntitiesRequestResult r = EntitiesRequests.put(C, path, ts);
            }
        }

        Student[] ss = (Student[]) EntitiesRequests.get(C, RequestConfig.STUDENTS_ENTITIES_QUERY, Student.class)
                .getDeserializedEntities();
        Student s = (Student) Arrays.stream(ss).filter(x -> x.getID() == studentsIds[0][0]).toArray()[0];
        StudentsSubject sss = s.getStudentssubjects()[0];

        Evaluation[] e = EntitiesTestLoaderTest.loadEvaluations();
        e[0].getStudentssubject().setIdStudentssubjects(sss.getID());
        e[1].getStudentssubject().setIdStudentssubjects(sss.getID());

        int[] ids = postTestEntities(e, Evaluation.class, RequestConfig.EVALUATIONS_ENTITIES_QUERY);
        return new int[][]{
                ids, studentsIds[0], studentsIds[1], studentsIds[2], studentsIds[3], studentsIds[4],
                subjectsIds[0], subjectsIds[1], subjectsIds[2]
        };
    }

    public static int[][] postTestRooms() throws Exception {
        int[] bIds = postTestBuildings()[0];

        Room[] e = EntitiesTestLoaderTest.loadRooms();
        e[0].getBuilding().setIdBuildings(bIds[0]);
        e[1].getBuilding().setIdBuildings(bIds[0]);

        int[] ids = postTestEntities(e, Room.class, RequestConfig.ROOMS_ENTITIES_QUERY);
        return new int[][]{ids, bIds};
    }

    public static int[][] postTestScheduleActionsDates() throws Exception {
        int[][] multipleSIds = postTestScheduleActions();

        ScheduleActionDate[] e = EntitiesTestLoaderTest.loadScheduleActionDates();

        e[0].getScheduleaction().setIdScheduleactions(multipleSIds[0][0]);
        e[1].getScheduleaction().setIdScheduleactions(multipleSIds[0][1]);

        int[] ids = postTestEntities(e, ScheduleActionDate.class, RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY);
        return new int[][]{ids, multipleSIds[0], multipleSIds[1], multipleSIds[2], multipleSIds[3], multipleSIds[4],
                multipleSIds[5], multipleSIds[6], multipleSIds[7]};
    }

    public static int[][] postTestScheduleActions() throws Exception {
        int[][] multipleRIds = postTestRooms();
        int[][] multipleSIds = postTestSubjects();
        int[] shIds = postTestSchoolHours()[0];
        int[] sdIds = postTestSchoolDays()[0];

        ScheduleAction[] e = EntitiesTestLoaderTest.loadScheduleActions();

        e[0].getRoom().setIdRooms(multipleRIds[0][0]);
        e[0].getSubject().setIdSubjects(multipleSIds[0][0]);
        e[0].getSchoolhour().setIdSchoolhours(shIds[0]);
        e[0].getSchoolday().setIdSchooldays(sdIds[0]);

        e[1].getRoom().setIdRooms(multipleRIds[0][1]);
        e[1].getSubject().setIdSubjects(multipleSIds[0][1]);
        e[1].getSchoolhour().setIdSchoolhours(shIds[1]);
        e[1].getSchoolday().setIdSchooldays(sdIds[1]);

        int[] ids = postTestEntities(e, ScheduleAction.class, RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY);
        return new int[][]{ids, multipleRIds[0], multipleRIds[1], multipleSIds[0], multipleSIds[1], multipleSIds[2],
                shIds, sdIds};
    }

    public static int[][] postTestSchoolDays() throws Exception {
        ASimpleEntity[] e = EntitiesTestLoaderTest.loadSchoolDays();
        int[] ids = postTestEntities(e, SchoolDay.class, RequestConfig.SCHOOLDAYS_ENTITIES_QUERY);
        return new int[][]{ids};
    }

    public static int[][] postTestSchoolHours() throws Exception {
        ASimpleEntity[] e = EntitiesTestLoaderTest.loadSchoolHours();
        int[] ids = postTestEntities(e, SchoolHour.class, RequestConfig.SCHOOLHOURS_ENTITIES_QUERY);
        return new int[][]{ids};
    }

    public static int[][] postTestStudents() throws Exception {
        int[][] multipleCIds = postTestClasses();
        int[] cIds = multipleCIds[0];

        Student[] e = EntitiesTestLoaderTest.loadStudents();
        e[0].getClassesEntity().setIdClasses(cIds[0]);
        e[1].getClassesEntity().setIdClasses(cIds[1]);

        int[] ids = postTestEntities(e, Student.class, RequestConfig.STUDENTS_ENTITIES_QUERY);
        return new int[][]{ids, multipleCIds[0], multipleCIds[1], multipleCIds[2], multipleCIds[3]};
    }

    public static int[][] postTestSubjects() throws Exception {
        int[] tIds = postTestTeachers()[0];
        int[] sIds = postTestSubjectsLists()[0];

        SubjectList ts = EntitiesTestLoaderTest.loadSubjectsLists()[0];
        ts.setSubjectName("");
        for (int tId : tIds) {
            String ps = "/";
            String path = RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.ID_QUERY + ps + tId
                    + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.ADD_QUERY;
            for (int sId : sIds) {
                ts.setIdSubjectlist(sId);
                EntitiesRequests.put(C, path, ts);
            }
        }

        Subject[] e = EntitiesTestLoaderTest.loadSubjects();
        e[0].getSubjectlist().setIdSubjectlist(sIds[0]);
        e[1].getSubjectlist().setIdSubjectlist(sIds[0]);
        e[0].getTeacher().setIdTeachers(tIds[0]);
        e[1].getTeacher().setIdTeachers(tIds[1]);

        int[] ids = postTestEntities(e, Subject.class, RequestConfig.SUBJECTS_ENTITIES_QUERY);
        return new int[][]{ids, tIds, sIds};
    }

    public static int[][] postTestSubjectsLists() throws Exception {
        ASimpleEntity[] e = EntitiesTestLoaderTest.loadSubjectsLists();
        int[] ids = postTestEntities(e, SubjectList.class, RequestConfig.SUBJECTLISTS_ENTITIES_QUERY);
        return new int[][]{ids};
    }

    public static int[][] postTestTeachers() throws Exception {
        ASimpleEntity[] e = EntitiesTestLoaderTest.loadTeachers();
        int[] ids = postTestEntities(e, Teacher.class, RequestConfig.TEACHERS_ENTITIES_QUERY);
        return new int[][]{ids};
    }

    public static void deleteTestAbsences(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.ABSENCE_ENTITIES_QUERY,
                RequestConfig.STUDENTS_ENTITIES_QUERY, RequestConfig.CLASSES_ENTITIES_QUERY,
                RequestConfig.TEACHERS_ENTITIES_QUERY, RequestConfig.ROOMS_ENTITIES_QUERY,
                RequestConfig.BUILDING_ENTITIES_QUERY, RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY,
                RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY,
                RequestConfig.ROOMS_ENTITIES_QUERY,
                RequestConfig.BUILDING_ENTITIES_QUERY, RequestConfig.SUBJECTS_ENTITIES_QUERY, RequestConfig.TEACHERS_ENTITIES_QUERY,
                RequestConfig.SUBJECTLISTS_ENTITIES_QUERY, RequestConfig.SCHOOLHOURS_ENTITIES_QUERY,
                RequestConfig.SCHOOLDAYS_ENTITIES_QUERY);
    }

    public static void deleteTestBuildings(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.BUILDING_ENTITIES_QUERY);
    }

    public static void deleteTestEvaluations(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.EVALUATIONS_ENTITIES_QUERY,
                RequestConfig.STUDENTS_ENTITIES_QUERY, RequestConfig.CLASSES_ENTITIES_QUERY,
                RequestConfig.TEACHERS_ENTITIES_QUERY, RequestConfig.ROOMS_ENTITIES_QUERY,
                RequestConfig.BUILDING_ENTITIES_QUERY, RequestConfig.SUBJECTS_ENTITIES_QUERY,
                RequestConfig.TEACHERS_ENTITIES_QUERY, RequestConfig.SUBJECTLISTS_ENTITIES_QUERY);
    }

    public static void deleteTestClasses(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.CLASSES_ENTITIES_QUERY, RequestConfig.TEACHERS_ENTITIES_QUERY,
                RequestConfig.ROOMS_ENTITIES_QUERY, RequestConfig.BUILDING_ENTITIES_QUERY);
    }

    public static void deleteTestRooms(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.ROOMS_ENTITIES_QUERY, RequestConfig.BUILDING_ENTITIES_QUERY);
    }

    public static void deleteTestScheduleActions(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY, RequestConfig.ROOMS_ENTITIES_QUERY,
                RequestConfig.BUILDING_ENTITIES_QUERY, RequestConfig.SUBJECTS_ENTITIES_QUERY, RequestConfig.TEACHERS_ENTITIES_QUERY,
                RequestConfig.SUBJECTLISTS_ENTITIES_QUERY, RequestConfig.SCHOOLHOURS_ENTITIES_QUERY,
                RequestConfig.SCHOOLDAYS_ENTITIES_QUERY);
    }

    public static void deleteTestScheduleActionDates(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY,
                RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY,
                RequestConfig.ROOMS_ENTITIES_QUERY,
                RequestConfig.BUILDING_ENTITIES_QUERY, RequestConfig.SUBJECTS_ENTITIES_QUERY, RequestConfig.TEACHERS_ENTITIES_QUERY,
                RequestConfig.SUBJECTLISTS_ENTITIES_QUERY, RequestConfig.SCHOOLHOURS_ENTITIES_QUERY,
                RequestConfig.SCHOOLDAYS_ENTITIES_QUERY);
    }

    public static void deleteTestSchoolDays(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.SCHOOLDAYS_ENTITIES_QUERY);
    }

    public static void deleteTestSchoolHours(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.SCHOOLHOURS_ENTITIES_QUERY);
    }

    public static void deleteTestStudents(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.STUDENTS_ENTITIES_QUERY, RequestConfig.CLASSES_ENTITIES_QUERY,
                RequestConfig.TEACHERS_ENTITIES_QUERY, RequestConfig.ROOMS_ENTITIES_QUERY,
                RequestConfig.BUILDING_ENTITIES_QUERY);
    }

    public static void deleteTestSubjects(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.SUBJECTS_ENTITIES_QUERY, RequestConfig.TEACHERS_ENTITIES_QUERY,
                RequestConfig.SUBJECTLISTS_ENTITIES_QUERY);
    }

    public static void deleteTestSubjectsLists(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.SUBJECTLISTS_ENTITIES_QUERY);
    }

    public static void deleteTestTeachers(int[][] ids) throws Exception {
        deleteTestEntities(ids, RequestConfig.TEACHERS_ENTITIES_QUERY);
    }

    @Test
    protected void testPostAbsences() throws Exception {
        int[][] ids = postTestAbsences();
        deleteTestAbsences(ids);
        Assertions.assertEquals(30, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostBuildings() throws Exception {
        int[][] ids = postTestBuildings();
        deleteTestBuildings(ids);
        Assertions.assertEquals(2, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostClasses() throws Exception {
        int[][] ids = postTestClasses();
        deleteTestClasses(ids);
        Assertions.assertEquals(8, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostEvaluations() throws Exception {
        int[][] ids = postTestEvaluations();
        deleteTestEvaluations(ids);
        Assertions.assertEquals(18, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostRooms() throws Exception {
        int[][] ids = postTestRooms();
        deleteTestRooms(ids);
        Assertions.assertEquals(4, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostScheduleActionsDates() throws Exception {
        int[][] ids = postTestScheduleActionsDates();
        deleteTestScheduleActionDates(ids);
        Assertions.assertEquals(18, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostScheduleActions() throws Exception {
        int[][] ids = postTestScheduleActions();
        deleteTestScheduleActions(ids);
        Assertions.assertEquals(16, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostSchoolDays() throws Exception {
        int[][] ids = postTestSchoolDays();
        deleteTestSchoolDays(ids);
        Assertions.assertEquals(2, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostSchoolHours() throws Exception {
        int[][] ids = postTestSchoolHours();
        deleteTestSchoolHours(ids);
        Assertions.assertEquals(2, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostStudents() throws Exception {
        int[][] ids = postTestStudents();
        deleteTestStudents(ids);
        Assertions.assertEquals(10, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostSubjects() throws Exception {
        int[][] ids = postTestSubjects();
        deleteTestSubjects(ids);
        Assertions.assertEquals(6, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostSubjectsLists() throws Exception {
        int[][] ids = postTestSubjectsLists();
        deleteTestSubjectsLists(ids);
        Assertions.assertEquals(2, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }

    @Test
    protected void testPostTeachers() throws Exception {
        int[][] ids = postTestTeachers();
        deleteTestTeachers(ids);
        Assertions.assertEquals(2, Arrays.stream(ids).flatMapToInt(Arrays::stream).count());
    }
}
