package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.RequestConfigTestConfigTest;
import cz.zcu.fav.kiv.mjakubas.saf.TestEntitiesPosterTest;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Arrays;
import java.util.Objects;

import static org.junit.jupiter.api.Assertions.*;

class AbsencesCommandsHandlerTest {

    private static final String ABSENCES_TEST_FILE_NAME = "test-absences";

    protected AbsencesCommandsHandler h = new AbsencesCommandsHandler(RequestConfigTestConfigTest.getTestConfig());
    protected int[][] ids;

    @BeforeEach
    void setUp() throws Exception {
        ids = TestEntitiesPosterTest.postTestAbsences();
    }

    @AfterEach
    void tearDown() throws Exception {
        TestEntitiesPosterTest.deleteTestAbsences(ids);
    }

    @Test
    void handleGetAllJSONTest() throws Exception {
        h.handleGetAll(FileType.JSON, ABSENCES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/absence/test-absences.json");
        expected = expected.replaceAll("-1a", "" + ids[0][0]);
        expected = expected.replaceAll("-2b", "" + ids[0][1]);

        expected = expected.replaceAll("-11", "" + ids[1][0]);
        expected = expected.replaceAll("-12", "" + ids[1][1]);

        expected = expected.replaceAll("-21", "" + ids[6][0]);
        expected = expected.replaceAll("-22", "" + ids[6][1]);

        String actual = Files.readString(Path.of(ABSENCES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTest() throws Exception {
        h.handleGetAll(FileType.XML, ABSENCES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/absence/test-absences.xml");
        expected = expected.replaceAll("-1a", "" + ids[0][0]);
        expected = expected.replaceAll("-2b", "" + ids[0][1]);

        expected = expected.replaceAll("-11", "" + ids[1][0]);
        expected = expected.replaceAll("-12", "" + ids[1][1]);

        expected = expected.replaceAll("-21", "" + ids[6][0]);
        expected = expected.replaceAll("-22", "" + ids[6][1]);

        String actual = Files.readString(Path.of(ABSENCES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllJSONTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.JSON, ABSENCES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/test-empty.json");

        String actual = Files.readString(Path.of(ABSENCES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.XML, ABSENCES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/absence/test-empty-absences.xml");

        String actual = Files.readString(Path.of(ABSENCES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    // --

    @Test
    void handlePostJSONSuccessful() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/json/test-post-absence.json"))
                        .getPath();
        String s = Files.readString(new File(path).toPath()).replaceAll("1a", "" + ids[6][0]);
        File file = File.createTempFile("temp", "test-frontend");
        Files.writeString(file.toPath(), s);

        h.handlePost(FileType.JSON, file.getAbsolutePath());

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;
    }

    @Test
    void handlePostXMLSuccessful() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/xml/test-post-absence.xml"))
                        .getPath();
        String s = Files.readString(new File(path).toPath()).replaceAll("1a", "" + ids[6][0]);
        File file = File.createTempFile("temp", "test-frontend");
        Files.writeString(file.toPath(), s);

        h.handlePost(FileType.XML, file.getAbsolutePath());

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;
    }

    @Test
    void handleDelete() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/json/test-post-absence.json"))
                        .getPath();
        String s = Files.readString(new File(path).toPath()).replaceAll("1a", "" + ids[6][0]);
        File file = File.createTempFile("temp", "test-frontend");
        Files.writeString(file.toPath(), s);

        h.handlePost(FileType.JSON, file.getAbsolutePath());
        h.handleDeleteByID(ids[0][ids[0].length - 1] + 1);
    }

    @Test
    void handleDeleteVoid() {
        Assertions.assertThrows(CommandException.class, () -> h.handleDeleteByID(0));
    }

    // --

    @Test
    void handlePostJSONUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/json/test-post-absence-e1.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/json/test-post-absence-e2.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostXMLUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/xml/test-post-absence-e1.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/absence/post/xml/test-post-absence-e2.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }
}