package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.RequestConfigTestConfigTest;
import cz.zcu.fav.kiv.mjakubas.saf.TestEntitiesPosterTest;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Arrays;
import java.util.Objects;

import static org.junit.jupiter.api.Assertions.*;

class ClassesCommandsHandlerTest {

    private static final String CLASSES_TEST_FILE_NAME = "test-classes";

    protected ClassesCommandsHandler h = new ClassesCommandsHandler(RequestConfigTestConfigTest.getTestConfig());
    protected int[][] ids;

    @BeforeEach
    void setUp() throws Exception {
        ids = TestEntitiesPosterTest.postTestClasses();
    }

    @AfterEach
    void tearDown() throws Exception {
        TestEntitiesPosterTest.deleteTestClasses(ids);
    }

    @Test
    void handleGetAllJSONTest() throws Exception {
        h.handleGetAll(FileType.JSON, CLASSES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/class/test-classes.json");
        expected = expected.replaceAll("-1a", "" + ids[0][0]);
        expected = expected.replaceAll("-2b", "" + ids[0][1]);

        expected = expected.replaceAll("-11", "" + ids[2][0]);
        expected = expected.replaceAll("-12", "" + ids[2][1]);

        expected = expected.replaceAll("-21", "" + ids[1][0]);
        expected = expected.replaceAll("-22", "" + ids[1][1]);

        String actual = Files.readString(Path.of(CLASSES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTest() throws Exception {
        h.handleGetAll(FileType.XML, CLASSES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/class/test-classes.xml");
        expected = expected.replaceAll("-1a", "" + ids[0][0]);
        expected = expected.replaceAll("-2b", "" + ids[0][1]);

        expected = expected.replaceAll("-11", "" + ids[2][0]);
        expected = expected.replaceAll("-12", "" + ids[2][1]);

        expected = expected.replaceAll("-21", "" + ids[1][0]);
        expected = expected.replaceAll("-22", "" + ids[1][1]);

        String actual = Files.readString(Path.of(CLASSES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllJSONTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.JSON, CLASSES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/test-empty.json");

        String actual = Files.readString(Path.of(CLASSES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.XML, CLASSES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/class/test-empty-classes.xml");

        String actual = Files.readString(Path.of(CLASSES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    // --

    @Test
    void handlePostJSONSuccessful() throws Exception {
        String preqRoom =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/test-req-room.json"))
                        .getPath();
        new RoomsCommandsHandler(RequestConfigTestConfigTest.getTestConfig()).handlePost(FileType.JSON, preqRoom);

        String preqTeacher =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/test-req-teacher.json"))
                        .getPath();
        new TeachersCommandsHandler(RequestConfigTestConfigTest.getTestConfig()).handlePost(FileType.JSON, preqTeacher);

        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/json/test-post-class.json"))
                        .getPath();
        h.handlePost(FileType.JSON, path);

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;

        int[] mt = Arrays.copyOf(ids[1], ids[1].length + 1);
        mt[mt.length - 1] = mt[mt.length - 2] + 1;
        ids[1] = mt;

        int[] mr = Arrays.copyOf(ids[2], ids[2].length + 1);
        mr[mr.length - 1] = mr[mr.length - 2] + 1;
        ids[2] = mr;
    }

    @Test
    void handlePostXMLSuccessful() throws Exception {
        String preqRoom =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/test-req-room.json"))
                        .getPath();
        new RoomsCommandsHandler(RequestConfigTestConfigTest.getTestConfig()).handlePost(FileType.JSON, preqRoom);

        String preqTeacher =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/test-req-teacher.json"))
                        .getPath();
        new TeachersCommandsHandler(RequestConfigTestConfigTest.getTestConfig()).handlePost(FileType.JSON, preqTeacher);

        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/xml/test-post-class.xml"))
                        .getPath();
        h.handlePost(FileType.XML, path);

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;

        int[] mt = Arrays.copyOf(ids[1], ids[1].length + 1);
        mt[mt.length - 1] = mt[mt.length - 2] + 1;
        ids[1] = mt;

        int[] mr = Arrays.copyOf(ids[2], ids[2].length + 1);
        mr[mr.length - 1] = mr[mr.length - 2] + 1;
        ids[2] = mr;
    }

    @Test
    void handleDelete() throws Exception {
        String preqRoom =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/test-req-room.json"))
                        .getPath();
        new RoomsCommandsHandler(RequestConfigTestConfigTest.getTestConfig()).handlePost(FileType.JSON, preqRoom);

        String preqTeacher =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/test-req-teacher.json"))
                        .getPath();
        new TeachersCommandsHandler(RequestConfigTestConfigTest.getTestConfig()).handlePost(FileType.JSON, preqTeacher);

        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/json/test-post-class.json"))
                        .getPath();
        h.handlePost(FileType.JSON, path);

        int[] mt = Arrays.copyOf(ids[1], ids[1].length + 1);
        mt[mt.length - 1] = mt[mt.length - 2] + 1;
        ids[1] = mt;

        int[] mr = Arrays.copyOf(ids[2], ids[2].length + 1);
        mr[mr.length - 1] = mr[mr.length - 2] + 1;
        ids[2] = mr;
        h.handleDeleteByID(ids[0][ids[0].length - 1] + 1);
    }

    @Test
    void handleDeleteVoid() {
        Assertions.assertThrows(CommandException.class, () -> h.handleDeleteByID(0));
    }

    // --

    @Test
    void handlePostJSONUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/json/test-post-class-e1.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/json/test-post-class-e2.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful3() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/json/test-post-class-e3.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostXMLUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/xml/test-post-class-e1.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/xml/test-post-class-e2.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful3() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/class/post/xml/test-post-class-e3.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }
}