package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.RequestConfigTestConfigTest;
import cz.zcu.fav.kiv.mjakubas.saf.TestEntitiesPosterTest;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Arrays;
import java.util.Objects;

import static org.junit.jupiter.api.Assertions.*;

class ScheduleActionsDatesCommandsHandlerTest {

    private static final String SCHEDULEACTIONSDATES_TEST_FILE_NAME = "test-scheduleactiondates";

    protected ScheduleActionsDatesCommandsHandler h = new ScheduleActionsDatesCommandsHandler(RequestConfigTestConfigTest.getTestConfig());
    protected int[][] ids;

    @BeforeEach
    void setUp() throws Exception {
        ids = TestEntitiesPosterTest.postTestScheduleActionsDates();
    }

    @AfterEach
    void tearDown() throws Exception {
        TestEntitiesPosterTest.deleteTestScheduleActionDates(ids);
    }

    @Test
    void handleGetAllJSONTest() throws Exception {
        h.handleGetAll(FileType.JSON, SCHEDULEACTIONSDATES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/scheduleactiondate/test-scheduleactiondates.json");
        expected = expected.replaceAll("-1a", "" + ids[0][0]);
        expected = expected.replaceAll("-2b", "" + ids[0][1]);

        expected = expected.replaceAll("-11", "" + ids[1][0]);
        expected = expected.replaceAll("-12", "" + ids[1][1]);

        expected = expected.replaceAll("-21", "" + ids[5][0]);
        expected = expected.replaceAll("-22", "" + ids[5][1]);

        expected = expected.replaceAll("-31", "" + ids[2][0]);
        expected = expected.replaceAll("-32", "" + ids[2][1]);

        expected = expected.replaceAll("-41", "" + ids[8][0]);
        expected = expected.replaceAll("-42", "" + ids[8][1]);

        expected = expected.replaceAll("-51", "" + ids[7][0]);
        expected = expected.replaceAll("-52", "" + ids[7][1]);

        String actual = Files.readString(Path.of(SCHEDULEACTIONSDATES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTest() throws Exception {
        h.handleGetAll(FileType.XML, SCHEDULEACTIONSDATES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/scheduleactiondate/test-scheduleactiondates.xml");
        expected = expected.replaceAll("-1a", "" + ids[0][0]);
        expected = expected.replaceAll("-2b", "" + ids[0][1]);

        expected = expected.replaceAll("-11", "" + ids[1][0]);
        expected = expected.replaceAll("-12", "" + ids[1][1]);

        expected = expected.replaceAll("-21", "" + ids[5][0]);
        expected = expected.replaceAll("-22", "" + ids[5][1]);

        expected = expected.replaceAll("-31", "" + ids[2][0]);
        expected = expected.replaceAll("-32", "" + ids[2][1]);

        expected = expected.replaceAll("-41", "" + ids[8][0]);
        expected = expected.replaceAll("-42", "" + ids[8][1]);

        expected = expected.replaceAll("-51", "" + ids[7][0]);
        expected = expected.replaceAll("-52", "" + ids[7][1]);

        String actual = Files.readString(Path.of(SCHEDULEACTIONSDATES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllJSONTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.JSON, SCHEDULEACTIONSDATES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/test-empty.json");

        String actual = Files.readString(Path.of(SCHEDULEACTIONSDATES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.XML, SCHEDULEACTIONSDATES_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/scheduleactiondate/test-empty-scheduleactiondates.xml");

        String actual = Files.readString(Path.of(SCHEDULEACTIONSDATES_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    // --

    @Test
    void handlePostJSONSuccessful() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/json/test-post-scheduleactiondate.json"))
                        .getPath();
        String s = Files.readString(new File(path).toPath()).replaceAll("1a", "" + ids[1][0]);
        File file = File.createTempFile("temp", "test-frontend");
        Files.writeString(file.toPath(), s);

        h.handlePost(FileType.JSON, file.getAbsolutePath());

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;
    }

    @Test
    void handlePostXMLSuccessful() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/xml/test-post-scheduleactiondate.xml"))
                        .getPath();
        String s = Files.readString(new File(path).toPath()).replaceAll("1a", "" + ids[1][0]);
        File file = File.createTempFile("temp", "test-frontend");
        Files.writeString(file.toPath(), s);

        h.handlePost(FileType.XML, file.getAbsolutePath());

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;
    }

    @Test
    void handleDelete() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/json/test-post-scheduleactiondate.json"))
                        .getPath();
        String s = Files.readString(new File(path).toPath()).replaceAll("1a", "" + ids[1][0]);
        File file = File.createTempFile("temp", "test-frontend");
        Files.writeString(file.toPath(), s);

        h.handlePost(FileType.JSON, file.getAbsolutePath());
        h.handleDeleteByID(ids[0][ids[0].length - 1] + 1);
    }

    @Test
    void handleDeleteVoid() {
        Assertions.assertThrows(CommandException.class, () -> h.handleDeleteByID(0));
    }

    // --

    @Test
    void handlePostJSONUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/json/test-post" +
                                        "-scheduleactiondate-e1.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/json/test-post" +
                                        "-scheduleactiondate-e2.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful3() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/json/test-post" +
                                        "-scheduleactiondate-e3.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostXMLUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/xml/test-post" +
                                        "-scheduleactiondate" +
                                        "-e1" +
                                        ".xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/xml/test-post" +
                                        "-scheduleactiondate" +
                                        "-e2" +
                                        ".xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful3() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/scheduleactiondate/post/xml/test-post" +
                                        "-scheduleactiondate" +
                                        "-e3" +
                                        ".xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }
}