package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.RequestConfigTestConfigTest;
import cz.zcu.fav.kiv.mjakubas.saf.TestEntitiesPosterTest;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.nio.file.Files;
import java.nio.file.Path;

import static org.junit.jupiter.api.Assertions.*;

class StudentsSubjectsCommandsHandlerTest {

    private static final String EVALUATIONS_TEST_FILE_NAME = "test-evaluations";

    protected StudentsSubjectsCommandsHandler h = new StudentsSubjectsCommandsHandler(RequestConfigTestConfigTest.getTestConfig());
    protected int[][] ids;

    @BeforeEach
    void setUp() throws Exception {
        ids = TestEntitiesPosterTest.postTestEvaluations();
    }

    @AfterEach
    void tearDown() throws Exception {
        TestEntitiesPosterTest.deleteTestEvaluations(ids);
    }

    @Test
    void handleGetAllJSONTest() throws Exception {
        h.handleGetAll(FileType.JSON, EVALUATIONS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/studentssubject/test-studentssubjects.json");
        expected = expected.replaceAll("\\d", "");

        String actual = Files.readString(Path.of(EVALUATIONS_TEST_FILE_NAME));
        actual = actual.replaceAll("\\d", "");

        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTest() throws Exception {
        h.handleGetAll(FileType.XML, EVALUATIONS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/studentssubject/test-studentssubjects.xml");
        expected = expected.replaceAll("\\d", "");

        String actual = Files.readString(Path.of(EVALUATIONS_TEST_FILE_NAME));
        actual = actual.replaceAll("\\d", "");

        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllJSONTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.JSON, EVALUATIONS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/test-empty.json");

        String actual = Files.readString(Path.of(EVALUATIONS_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.XML, EVALUATIONS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/studentssubject/test-empty-studentssubjects.xml");

        String actual = Files.readString(Path.of(EVALUATIONS_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }
}