package cz.zcu.fav.kiv.mjakubas.saf.command.handler;

import cz.zcu.fav.kiv.mjakubas.saf.RequestConfigTestConfigTest;
import cz.zcu.fav.kiv.mjakubas.saf.TestEntitiesPosterTest;
import cz.zcu.fav.kiv.mjakubas.saf.command.exception.CommandException;
import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Arrays;
import java.util.Objects;

import static org.junit.jupiter.api.Assertions.*;

class TeachersCommandsHandlerTest {

    private static final String TEACHERS_TEST_FILE_NAME = "test-teachers";

    protected TeachersCommandsHandler h = new TeachersCommandsHandler(RequestConfigTestConfigTest.getTestConfig());
    protected int[][] ids;

    @BeforeEach
    void setUp() throws Exception {
        ids = TestEntitiesPosterTest.postTestTeachers();
    }

    @AfterEach
    void tearDown() throws Exception {
        TestEntitiesPosterTest.deleteTestTeachers(ids);
    }

    @Test
    void handleGetAllJSONTest() throws Exception {
        h.handleGetAll(FileType.JSON, TEACHERS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/teacher/test-teachers.json");
        expected = expected.replaceAll("-1", "" + ids[0][0]);
        expected = expected.replaceAll("-2", "" + ids[0][1]);

        String actual = Files.readString(Path.of(TEACHERS_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTest() throws Exception {
        h.handleGetAll(FileType.XML, TEACHERS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/teacher/test-teachers.xml");
        expected = expected.replaceAll("-1", "" + ids[0][0]);
        expected = expected.replaceAll("-2", "" + ids[0][1]);

        String actual = Files.readString(Path.of(TEACHERS_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllJSONTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.JSON, TEACHERS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/test-empty.json");

        String actual = Files.readString(Path.of(TEACHERS_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    @Test
    void handleGetAllXMLTestEmpty() throws Exception {
        tearDown();
        ids = new int[][]{new int[]{}};

        h.handleGetAll(FileType.XML, TEACHERS_TEST_FILE_NAME);
        String expected = EntitiesStringComparatorTest.getExpectedContentString("commands/teacher/test-empty-teachers.xml");

        String actual = Files.readString(Path.of(TEACHERS_TEST_FILE_NAME));
        assertEquals(expected, actual);
    }

    // --

    @Test
    void handlePostJSONSuccessful() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher.json"))
                        .getPath();
        h.handlePost(FileType.JSON, path);

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;
    }

    @Test
    void handlePostXMLSuccessful() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher.xml"))
                        .getPath();
        h.handlePost(FileType.XML, path);

        int[] ms = Arrays.copyOf(ids[0], ids[0].length + 1);
        ms[ms.length - 1] = ms[ms.length - 2] + 1;
        ids[0] = ms;
    }

    @Test
    void handleDelete() throws Exception {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher.json"))
                        .getPath();
        h.handlePost(FileType.JSON, path);
        h.handleDeleteByID(ids[0][ids[0].length - 1] + 1);
    }

    @Test
    void handleDeleteVoid() {
        Assertions.assertThrows(CommandException.class, () -> h.handleDeleteByID(0));
    }

    // --

    @Test
    void handlePostJSONUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e1.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e2.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful3() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e3.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful4() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e4.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful5() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e5.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful6() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e6.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    @Test
    void handlePostJSONUnsuccessful7() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/json/test-post-teacher-e7.json"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.JSON, path));
    }

    // --

    @Test
    void handlePostXMLUnsuccessful1() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e1.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful2() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e2.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful3() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e3.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful4() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e4.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful5() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e5.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful6() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e6.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    @Test
    void handlePostXMLUnsuccessful7() {
        String path =
                Objects.requireNonNull(this.getClass()
                                .getClassLoader().getResource("commands/teacher/post/xml/test-post-teacher-e7.xml"))
                        .getPath();
        Assertions.assertThrows(CommandException.class, () -> h.handlePost(FileType.XML, path));
    }

    // --
}