package cz.zcu.fav.kiv.mjakubas.saf.parser.args;

import cz.zcu.fav.kiv.mjakubas.saf.parser.filetype.FileType;
import cz.zcu.fav.kiv.mjakubas.saf.parser.tokenizer.Token;
import cz.zcu.fav.kiv.mjakubas.saf.parser.tokenizer.Tokenizer;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import static org.junit.jupiter.api.Assertions.*;

class ArgsParserTest {

    ArgsParser parser;

    public static final char C = Tokenizer.COMMAND_STRING_TOKEN_IDENTIFIER;
    public static final char V = Tokenizer.CLASS_TOKEN_IDENTIFIER;

    public static final char F = Tokenizer.FILETYPE_CLASS_TOKEN_IDENTIFIER;

    @BeforeEach
    void setUp() throws IOException {
        Properties properties = new Properties();
        properties.load(this.getClass().getClassLoader().getResourceAsStream("config.cmd.properties"));
        parser = new ArgsParser(properties);
    }

    @AfterEach
    void tearDown() {
    }

    @Test
    void isValidStringValue1() {
        assertTrue(parser.isValidStringValue("valid", new Token("valid")));
    }

    @Test
    void isValidStringValue2() {
        assertFalse(parser.isValidStringValue("valid", new Token("notValid")));
    }

    @Test
    void parseClassValueTestGeneric() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertTrue(parser.parseClassValue("genericValue", new Token(String.class), mr, ma));
    }

    @Test
    void parseClassValueTestGeneric1() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseClassValue("genericValue", new Token(String.class), mr, ma);
        assertEquals(mr.get(0), String.class);
        assertEquals(ma.get(0), "genericValue");

    }

    @Test
    void parseClassValueTestInteger() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertTrue(parser.parseClassValue("0", new Token(Integer.class), mr, ma));
    }

    @Test
    void parseClassValueTestInteger1() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseClassValue("0", new Token(Integer.class), mr, ma);
        assertEquals(mr.get(0), Integer.class);
        assertEquals(ma.get(0), 0);

    }

    @Test
    void parseClassValueTestFiletype1XML() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertTrue(parser.parseClassValue("--XML", new Token(FileType.class), mr, ma));
    }

    @Test
    void parseClassValueTestFiletype2XML() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseClassValue("--XML", new Token(FileType.class), mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertEquals(ma.get(0), FileType.XML);
    }

    @Test
    void parseClassValueTestFiletype1JSON() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertTrue(parser.parseClassValue("--JSON", new Token(FileType.class), mr, ma));
    }

    @Test
    void parseClassValueTestFiletype2JSON() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseClassValue("--JSON", new Token(FileType.class), mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertEquals(ma.get(0), FileType.JSON);

    }

    @Test
    void parseFileTypeValueTestXML() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertTrue(parser.parseFileTypeValue("--XML", mr, ma));
    }

    @Test
    void parseFileTypeValueTestJSON() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertTrue(parser.parseFileTypeValue("--JSON", mr, ma));
    }

    @Test
    void parseFileTypeValueTestXML2() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseFileTypeValue("--XML", mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertEquals(ma.get(0), FileType.XML);
    }

    @Test
    void parseFileTypeValueTestJSON2() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseFileTypeValue("--JSON", mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertEquals(ma.get(0), FileType.JSON);
    }

    @Test
    void parseFileTypeValueTestXML2W() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseFileTypeValue("--XML", mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertNotEquals(ma.get(0), FileType.JSON);
    }

    @Test
    void parseFileTypeValueTestJSON2W() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseFileTypeValue("--JSON", mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertNotEquals(ma.get(0), FileType.XML);
    }

    @Test
    void parseFileTypeValueTestUnknown() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        assertFalse(parser.parseFileTypeValue("--Unknown", mr, ma));
    }

    @Test
    void parseIntegerValueTest1() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        Assertions.assertFalse(parser.parseIntegerValue("stringValue", mr, ma));
    }

    @Test
    void parseIntegerValueTest2() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseIntegerValue("1", mr, ma);
        assertEquals(mr.get(0), Integer.class);
        assertEquals(ma.get(0), 1);
    }

    @Test
    void parseIntegerValueTest3() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        Assertions.assertTrue(parser.parseIntegerValue("1", mr, ma));
    }

    @Test
    void parseGenericClassValueTest1() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseGenericClassValue("genericValue", new Token(String.class), mr, ma);
        assertEquals(mr.get(0), String.class);
        assertEquals(ma.get(0), "genericValue");
    }

    @Test
    void parseGenericClassValueTest2() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        parser.parseGenericClassValue("genericValue", new Token(String.class), mr, ma);
        assertEquals(mr.get(0), String.class);
        assertNotEquals(ma.get(0), "differentGenericValue");
    }

    @Test
    void parseArgsF() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        String[] args = new String[]{"a"};
        List<Token> tokens = new ArrayList<>();

        assertFalse(parser.parseArgs(args, tokens, mr, ma));
    }

    @Test
    void parseArgsT() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        String[] args = new String[]{"--xml"};
        List<Token> tokens = new ArrayList<>();
        tokens.add(new Token(FileType.class));

        assertTrue(parser.parseArgs(args, tokens, mr, ma));
    }

    @Test
    void parseArgsT1() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        String[] args = new String[]{"--xml", "0", "a"};
        List<Token> tokens = new ArrayList<>();
        tokens.add(new Token(FileType.class));
        tokens.add(new Token(Integer.class));
        tokens.add(new Token(String.class));

        assertTrue(parser.parseArgs(args, tokens, mr, ma));
    }

    @Test
    void parseArgsT1A() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        String[] args = new String[]{"--xml", "0", "a"};
        List<Token> tokens = new ArrayList<>();
        tokens.add(new Token(FileType.class));
        tokens.add(new Token(Integer.class));
        tokens.add(new Token(String.class));

        parser.parseArgs(args, tokens, mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertEquals(ma.get(0), FileType.XML);

        assertEquals(mr.get(1), Integer.class);
        assertEquals(ma.get(1), 0);

        assertEquals(mr.get(2), String.class);
        assertEquals(ma.get(2), "a");
    }

    @Test
    void parseArgsT2A() {
        List<Class<?>> mr = new ArrayList<>();
        List<Object> ma = new ArrayList<>();
        String[] args = new String[]{"--JSON", "0", "a"};
        List<Token> tokens = new ArrayList<>();
        tokens.add(new Token(FileType.class));
        tokens.add(new Token(Integer.class));
        tokens.add(new Token(String.class));

        parser.parseArgs(args, tokens, mr, ma);
        assertEquals(mr.get(0), FileType.class);
        assertEquals(ma.get(0), FileType.JSON);

        assertEquals(mr.get(1), Integer.class);
        assertEquals(ma.get(1), 0);

        assertEquals(mr.get(2), String.class);
        assertEquals(ma.get(2), "a");
    }
}