package cz.zcu.fav.kiv.mjakubas.saf.parser.mapper;

import cz.zcu.fav.kiv.mjakubas.saf.parser.mapper.exception.MapperException;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;

/**
 * Test general implementation of mapper.
 */
class IMapperTest {

    IMapper[] m = new IMapper[]{new JSONMapper(), new XMLMapper()};
    A testObject;

    @BeforeEach
    void setUp() {
        testObject = new A();
        testObject.setNumber(5);
        testObject.setText("a");

        B b = new B();
        b.setArray(new int[]{0, 1, 2, 3});
        testObject.setB(b);
    }

    @AfterEach
    void tearDown() {
    }

    @Test
    void testImplementation() throws MapperException {
        for (IMapper mapper : m) {
            String serialization = mapper.serialize(testObject);
            A deserialization = mapper.deserializeOne(serialization, A.class);
            assertEquals(testObject, deserialization);
        }
    }

    @Test
    void testMultipleImplementation() throws MapperException {
        for (IMapper mapper : m) {
            String serialization = mapper.serialize(new A[]{testObject, testObject});
            A[] deserialization = mapper.deserialize(serialization, A.class);
            for (A a : deserialization) {
                assertEquals(a, testObject);
            }
        }
    }

    @Test
    void testEmptyImplementation() {
        String serialization = "";
        for (IMapper mapper : m) {
            Assertions.assertThrows(MapperException.class, () -> mapper.deserializeOne(serialization, A.class));
        }
    }

    @Test
    void testEmptyImplementationArray() {
        String serialization = "";
        for (IMapper mapper : m) {
            Assertions.assertThrows(MapperException.class, () -> mapper.deserialize(serialization, A.class));
        }
    }

    @Test
    void testMalformed() {
        String serialization = "-";
        for (IMapper mapper : m) {
            Assertions.assertThrows(MapperException.class, () -> mapper.deserialize(serialization, A.class));
        }
    }
}