package cz.zcu.fav.kiv.mjakubas.saf.request;

import cz.zcu.fav.kiv.mjakubas.saf.config.*;
import cz.zcu.fav.kiv.mjakubas.saf.config.configs.*;
import cz.zcu.fav.kiv.mjakubas.saf.entity.*;
import cz.zcu.fav.kiv.mjakubas.saf.request.basicrequest.exception.*;
import org.junit.jupiter.api.*;

import java.io.*;

/**
 * Tests cover right back--end addresses that they exist → don't throw 404 error.
 */
class EntitiesRequestsATest {

    RequestConfig requestConfig;

    @BeforeEach
    void setUp() throws IOException {
        requestConfig = ConfigManager.getManager().getRequestConfig();
    }

    @Test
    void testA1() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY,
                    Absence.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA2() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Absence.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA3() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY + RequestConfig.STUDENT_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Absence.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA4() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY + RequestConfig.STUDENT_QUERY + RequestConfig.NAME_QUERY + "/" + "Jan" + "/" + "Zelený",
                    Absence.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA5() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY + RequestConfig.SCHEDULEACTIONDATE_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Absence.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA6() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY,
                    new Object[]{});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA7() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    new Absence(1, 2, 2));
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA8() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.ABSENCE_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1000);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA9() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA10() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1000,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA11() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/" + "name",
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA12() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1000,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA13() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/" + "name",
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA14() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.ID_QUERY + "/" + 1000,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA15() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY,
                    new Object[]{new Building()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA16() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    new Building());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA17() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 100000);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA18() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA19() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA20() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.BUILDING_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/" + 1,
                    Building.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA21() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY,
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA22() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA23() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/" + "name",
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA24() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.STUDENT_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA25() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY +  RequestConfig.STUDENT_QUERY + RequestConfig.NAME_QUERY + "/" + "A" + "/" + "A",
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA26() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA27() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY + RequestConfig.NAME_QUERY + "/" + "a" + "/" + "a",
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA28() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA29() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.NAME_QUERY + "/" + "a",
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA30() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/" + 1,
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA31() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY + "/" + "a",
                    Class.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA32() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY,
                    new Object[]{new Student()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA33() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/" + "1",
                    new Student());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA34() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100" + RequestConfig.SUBJECT_QUERY + RequestConfig.ADD_QUERY,
                    new Object[]{new Subject()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA35() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100" + RequestConfig.SUBJECT_QUERY + RequestConfig.REMOVE_QUERY,
                    new Object[]{new Subject()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA36() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.CLASSES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/1000000");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA37() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY,
                    Evaluation.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA38() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    Evaluation.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA39() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.STUDENTSSUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    Evaluation.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA40() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY,
                    new Object[]{new Evaluation()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA41() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new Evaluation());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA42() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.EVALUATIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/10000");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA43() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY,
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA44() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA45() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA46() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.CAPACITY_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA47() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.BUILDING_QUERY + RequestConfig.ID_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA48() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.BUILDING_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA49() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.CLASS_QUERY + RequestConfig.ID_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA50() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.CLASS_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA51() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY,
                    new Object[]{new Room()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA52() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new Room());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA53() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.ROOMS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA54() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY,
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA55() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA56() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.ID_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA57() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ROOM_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA58() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA59() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Room.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA60() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY,
                    new Object[]{new ScheduleAction()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA61() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new ScheduleAction());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA62() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.SCHEDULEACTIONS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA63() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY,
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA64() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA65() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA66() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.SUBSTITUTION_QUERY,
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA67() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.SUBSTITUTION_QUERY + RequestConfig.DATE_QUERY + "/2000-01-01",
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA68() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.SUBSTITUTION_QUERY + RequestConfig.DATE_QUERY + "/2000-01-01"
                            + RequestConfig.TEACHER_QUERY + RequestConfig.ID_QUERY + "/100",
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA69() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.SUBSTITUTION_QUERY + RequestConfig.DATE_QUERY + "/2000-01-01"
                            + RequestConfig.STUDENT_QUERY + RequestConfig.ID_QUERY + "/100",
                    ScheduleActionDate.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA70() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY,
                    new Object[]{new ScheduleActionDate()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA71() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.SCHEDULEACTIONDATES_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA72() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY,
                    SchoolDay.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA73() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    SchoolDay.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA74() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a",
                    SchoolDay.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA75() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTION_QUERY + RequestConfig.ID_QUERY + "/100",
                    SchoolDay.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA76() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTIONDATE_QUERY + RequestConfig.ID_QUERY + "/100",
                    SchoolDay.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA77() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY,
                    new Object[]{new SchoolDay()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA78() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new SchoolDay());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA79() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.SCHOOLDAYS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100000");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA80() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY,
                    SchoolHour.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA81() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    SchoolHour.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA82() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a",
                    SchoolHour.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA83() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTION_QUERY + RequestConfig.ID_QUERY + "/100",
                    SchoolHour.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA84() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTIONDATE_QUERY + RequestConfig.ID_QUERY + "/100",
                    SchoolHour.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA85() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY,
                    new Object[]{new SchoolHour()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA86() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new Object[]{new SchoolHour()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA87() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.SCHOOLHOURS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100000");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA88() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY,
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA89() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA90() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a/b",
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA91() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.CLASS_QUERY + RequestConfig.ID_QUERY + "/100",
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA92() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.CLASS_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA93() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA94() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Student.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA95() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY,
                    new Object[]{new Student()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA96() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100" + RequestConfig.SUBJECT_QUERY + RequestConfig.ADD_QUERY,
                   new Student());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA97() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100" +
                            RequestConfig.SUBJECT_QUERY + RequestConfig.REMOVE_QUERY,
                    new Student());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA98() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.STUDENTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA99() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTSSUBJECTS_ENTITIES_QUERY,
                    StudentsSubject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA100() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTSSUBJECTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    StudentsSubject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA101() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.STUDENTSSUBJECTS_ENTITIES_QUERY + RequestConfig.STUDENT_QUERY +
                            RequestConfig.ID_QUERY + "/100" + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    StudentsSubject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA102() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY,
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA103() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA104() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA105() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.ID_QUERY + "/100",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA106() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA107() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.CLASS_QUERY + RequestConfig.ID_QUERY + "/100",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA108() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.CLASS_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA109() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.SCHEDULEACTION_QUERY + RequestConfig.ID_QUERY + "/100",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA110() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY + RequestConfig.ID_QUERY + "/100",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA111() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY + RequestConfig.NAME_QUERY + "/a/b",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA112() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.STUDENT_QUERY + RequestConfig.ID_QUERY + "/100",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA113() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.STUDENT_QUERY + RequestConfig.NAME_QUERY + "/a/b",
                    Subject.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA114() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY,
                    new Object[]{new Subject()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA115() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new Subject());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA116() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.SUBJECTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA117() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY,
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA118() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA119() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA120() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA121() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY + "/a",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA122() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY+ RequestConfig.ID_QUERY + "/100",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA123() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.TEACHER_QUERY+ RequestConfig.NAME_QUERY + "/a/b",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA124() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY,
                    new Object[]{SubjectList.class});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA125() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    SubjectList.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA126() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.SUBJECTLISTS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/10000000");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA127() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY,
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA128() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY+ RequestConfig.ID_QUERY + "/100",
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA129() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.NAME_QUERY + "/a/b",
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA130() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.ID_QUERY + "/100",
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA131() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA132() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.NAME_QUERY + "/a",
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA133() {
        try {
            EntitiesRequests.get(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.SUBJECT_QUERY + RequestConfig.ID_QUERY + "/100",
                    Teacher.class);
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA134() {
        try {
            EntitiesRequests.post(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY,
                    new Object[]{new Teacher()});
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA135() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100",
                    new Teacher());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA136() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100" + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.ADD_QUERY,
                    new Teacher());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA137() {
        try {
            EntitiesRequests.put(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100" + RequestConfig.SUBJECTLIST_QUERY + RequestConfig.REMOVE_QUERY,
                    new Teacher());
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }

    @Test
    void testA138() {
        try {
            EntitiesRequests.delete(requestConfig,
                    RequestConfig.TEACHERS_ENTITIES_QUERY + RequestConfig.ID_QUERY + "/100000");
        } catch (RequestErrorException e) {
            Assertions.assertFalse(e.getMessage().contains(":404"));
        }
    }
}